@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcontent.php 5850 2009-07-28 19:06:52Z calguy1000 $
+#$Id: listcontent.php 5996 2009-09-16 14:04:49Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -271,7 +271,7 @@ function setactive($contentid, $active = true)
 	if($permission)
 	  {
 		$node = &$hierManager->getNodeById($contentid);
-		$value =& $node->getContent(false,true,true);
+		$value =& $node->getContent();
 		$value->SetActive($active);
 		$value->Save();
 		global $gCms;
@@ -352,7 +352,12 @@ function movecontent($contentid, $parentid, $direction = 'down')
 function deletecontent($contentid)
 {
 	$userid = get_userid();
-	$access = check_permission($userid, 'Remove Pages') || check_permission($userid, 'Manage All Content');
+	$mypages = author_pages($userid);
+
+	$access = (check_permission($userid, 'Remove Pages') &&
+	  (check_ownership($userid,$contentid) ||
+	   quick_check_authorship($contentid,$mypages)))
+	  || check_permission($userid, 'Manage All Content');
 	
 	global $gCms;
 	$hierManager =& $gCms->GetHierarchyManager();
@@ -739,7 +744,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 	{
 	  $columns['active'] = '&nbsp;';
 	  $txt = '';
-	  if (check_permission($userid, 'Manage All Content'))
+	  if (check_permission($userid, 'Manage All Content') && $one->Type() != 'errorpage' )
 	    {
 	      if($one->Active())
 		{
@@ -845,8 +850,9 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 	  $columns['copy'] = '&nbsp;';
 	  $txt = '';
 	  if( $one->IsCopyable() && 
-	      (check_permission($userid,'Add Pages') || check_permission($userid,'Manage All Content')) &&
-	      (check_ownership($userid, $one->Id()) || quick_check_authorship($one->Id(), $mypages)) )
+	      ((check_permission($userid,'Add Pages') &&
+		(check_ownership($userid, $one->Id()) || quick_check_authorship($one->Id(), $mypages)))
+	       || check_permission($userid,'Manage All Content')) )
 	    {
 	      $txt .= '<a href="copycontent.php'.$urlext.'&amp;content_id='.$one->Id().'">';
 	      $txt .= $copyImg."</a>";
@@ -888,7 +894,11 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$templates, &$users, &
 	  if ($one->DefaultContent() != true)
 	    {
 	      if ($root->getChildrenCount() == 0 && 
-		  (check_permission($userid, 'Remove Pages') || check_permission($userid,'Manage All Content')) )
+		  ((check_permission($userid, 'Remove Pages') &&
+		    (check_ownership($userid,$one->Id()) || 
+		     quick_check_authorship($one->Id(),$mypages)))
+		   || check_permission($userid,'Manage All Content')) 
+		 )
 		{
 		  $txt .= "<a href=\"{$thisurl}&amp;deletecontent=".$one->Id()."\" onclick=\"if (confirm('".cms_html_entity_decode_utf8(lang('deleteconfirm', $one->mName), true)."')) xajax_content_delete(".$one->Id()."); return false;\">";
 		  $txt .= $deleteImg;
