@@ -1,4 +1,6 @@
 <?php
+$lang['invalidemail'] = 'The email address entered is invalid';
+$lang['empty_query'] = 'Empty query?? %s';
 $lang['no_db_driver'] = 'No compatible database drivers found';
 $lang['test_check_output_buffering'] = 'Checking output buffering';
 $lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
@@ -199,7 +201,7 @@ $lang['install_thanks'] = 'Thanks for installing CMS Made Simple';
 $lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
 $lang['upgrade_system'] = 'Upgrade System';
 $lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
-$lang['install_please_read'] = 'Please read the <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Installation Troubleshooting</a> page in the CMS Made Simple Documentation Wiki.';
+$lang['install_please_read'] = 'Please read the <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Installation Troubleshooting</a> page in the CMS Made Simple Documentation Wiki.';
 $lang['install_checking'] = 'Checking permissions and PHP settings';
 $lang['install_test'] = 'Test';
 $lang['install_result'] = 'Result';
@@ -297,10 +299,10 @@ $lang['test_check_ini_set'] = 'Checking if ini_set works';
 $lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
 
 $lang['install_admin_header'] = 'Admin Account Information';
-$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere, as there will be no other way to login to your CMS Made Simple admin system without it.';
+$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere.';
 $lang['install_admin_email'] = 'E-mail Address';
 $lang['install_admin_email_info'] = 'E-Mail Account Information';
-$lang['install_admin_email_note'] = '<strong>Note:</strong> This function uses the php\'s mail function. If you don\'t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
+$lang['install_admin_email_note'] = '<strong>Note:</strong> This task uses the php\'s mail function. If you don\'t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
 
 $lang['install_admin_sitename'] = 'This is the name of your site. It will be used in various places of the default templates and can be used anywhere with the {sitename} tag.';
 $lang['install_admin_db'] = 'Database Information';
@@ -309,7 +311,7 @@ $lang['install_admin_db_info'] = <<<EOT
 <p>For MySQL, use the following:</p>
 <p>Log in to mysql from a console and run the following commands:</p>
 <ol>
-<li>create database cms; (use whatever name you want here but make sure to remember it, you&apos;ll need to enter it on this page)</li>
+<li>create database cms; (use whatever name you want here but make sure to remember it, you'll need to enter it on this page)</li>
 <li>grant all privileges on cms.* to cms_user@localhost identified by 'cms_pass';</li>
 </ol>
 EOT;
