@@ -1,15 +1,17 @@
 <?php
+$lang['invalidemail'] = 'Vložen&aacute; emailov&aacute; adresa je neplatn&aacute;';
+$lang['empty_query'] = 'Pr&aacute;zdn&yacute; dotaz?? %s';
 $lang['no_db_driver'] = 'Nenalezeny kompatibiln&iacute; ovladače datab&aacute;ze';
-$lang['test_check_output_buffering'] = 'Kontroluji v&yacute;stupn&iacute; vyrovn&aacute;v&aacute;n&iacute;';
+$lang['test_check_output_buffering'] = 'Kontroluje se v&yacute;stupn&iacute; vyrovn&aacute;v&aacute;n&iacute;';
 $lang['test_check_output_buffering_failed'] = 'V&yacute;stupn&iacute; vyrovn&aacute;v&aacute;n&iacute; je zak&aacute;z&aacute;no. Pravděpodobně nebudete moci použ&iacute;vat ž&aacute;dnou funkcionalitu, kter&aacute; to vyžaduje';
 $lang['phpinfo'] = 'Zobrazit informace o PHP';
 $lang['mod_security'] = 'Apache Mod Security';
-$lang['test_check_tempnam'] = 'Kontroluji tempnam funkci';
+$lang['test_check_tempnam'] = 'Kontroluje se tempnam funkce';
 $lang['test_check_db_drivers'] = 'Ovladače datab&aacute;ze';
 $lang['test_check_db_drivers_failed'] = 'Nebyly nalezeny ovladače datab&aacute;ze';
-$lang['test_check_register_globals'] = 'Kontrola register_globals';
+$lang['test_check_register_globals'] = 'Kontroluje se register_globals';
 $lang['test_check_register_globals_failed'] = 'V nastaven&iacute; PHP je aktivov&aacute;na volba register_globals. Z bezpečnostn&iacute;ch důvodů pros&iacute;m pož&aacute;dejte o vypnut&iacute; t&eacute;to volby.';
-$lang['test_check_disable_functions'] = 'Kontrola zak&aacute;zan&yacute;ch funkc&iacute; v PHP';
+$lang['test_check_disable_functions'] = 'Kontroluj&iacute; se zak&aacute;zan&eacute; funkce v PHP';
 $lang['test_check_disable_functions_failed'] = 'Toto je seznam funkc&iacute; zak&aacute;zan&yacute;ch na va&scaron;em serveru.';
 $lang['install_admin_db_port'] = 'Port Datab&aacute;ze';
 $lang['install_admin_db_port_info'] = 'Pokud si nejse jisti, zanechte toto pr&aacute;zdn&eacute; pro v&yacute;choz&iacute; nastaven&iacute;.';
@@ -106,7 +108,7 @@ $lang['upload_max_filesize'] = 'Maxim&aacute;ln&iacute; velikost nahr&aacute;van
 $lang['post_max_size'] = 'Maxim&aacute;ln&iacute; veilkost dat, zas&iacute;lan&yacute;ch metodou POST (Maximum post size)';
 $lang['memory_limit'] = 'Paměťov&yacute; limit v PHP';
 $lang['server_db_type'] = 'Datab&aacute;zov&yacute; server';
-$lang['server_db_version'] = 'Verez datab&aacute;zov&eacute;ho serveru';
+$lang['server_db_version'] = 'Verze datab&aacute;zov&eacute;ho serveru';
 $lang['phpversion'] = 'Verze PHP';
 $lang['safe_mode'] = 'PHP Safe Mode';
 $lang['php_information'] = 'Informace PHP';
@@ -158,8 +160,8 @@ $lang['errordeletingfile'] = 'Nelze smazat soubor. Probl&eacute;m s opr&aacute;v
 $lang['errordirectorynotwritable'] = 'Nejsou opr&aacute;vněn&iacute; pro z&aacute;pis do adres&aacute;ře. Toto může b&yacute;t způsobeno opr&aacute;vněn&iacute;mi souboru a vlastnictv&iacute;m. Tak&eacute; může b&yacute;t povolen safe mod.';
 $lang['cachenotwritable'] = 'Adres&aacute;ř ke&scaron;e nen&iacute; zapisovateln&yacute;. Vyči&scaron;těn&iacute; ke&scaron;e nebude fungovat. Nastavte, pros&iacute;m, adres&aacute;ři tmp/cache pln&aacute; opr&aacute;vněn&iacute; pro čten&iacute;/z&aacute;pis/spu&scaron;těn&iacute; (chmod 777). Tak&eacute; je třeba zak&aacute;zat safe mod.';
 $lang['modulesnotwritable'] = 'Adres&aacute;ř modulů nen&iacute; zapisovateln&yacute;. Pokud budete cht&iacute;t instalovat moduly nahr&aacute;n&iacute;m XML souboru, je třeba nastavit pln&aacute; pr&aacute;va čten&iacute;/z&aacute;pisu/spou&scaron;těn&iacute; (chmod 777) adres&aacute;ři modulů. Tak&eacute; může b&yacute;t aktivn&iacute; safe mod.';
-$lang['false'] = 'False';
-$lang['settrue'] = 'Set True';
+$lang['false'] = 'Ne';
+$lang['settrue'] = 'Nastavit Ano';
 $lang['filename'] = 'Jm&eacute;no souboru';
 $lang['filesize'] = 'Velikost souboru';
 $lang['help'] = 'N&aacute;pověda';
@@ -170,8 +172,8 @@ $lang['password'] = 'Heslo';
 $lang['passwordagain'] = 'Heslo (znovu)';
 $lang['remove'] = 'Odstranit';
 $lang['saveconfig'] = 'Uložit config';
-$lang['true'] = 'True';
-$lang['setfalse'] = 'Set False';
+$lang['true'] = 'Ano';
+$lang['setfalse'] = 'Nastavit Ne';
 $lang['type'] = 'Typ';
 $lang['typenotvalid'] = 'Typ nen&iacute; spr&aacute;vn&yacute;';
 $lang['unknown'] = 'Nezn&aacute;m&yacute;';
@@ -205,7 +207,7 @@ $lang['install_value_recommended'] = 'Nastaven&iacute; je nad požadovanou hodno
 $lang['install_value_exceed'] = 'Nastaven&iacute; vyhovuje doporučen&yacute;m hodnot&aacute;m<br />nebo... Je dostupn&aacute; schopnost, kter&aacute; <em>může</em> b&yacute;t požadov&aacute;na pro někter&eacute; funkce';
 $lang['install_test_failed'] = 'Jeden nebo v&iacute;ce testů selhal. St&aacute;le můžete syst&eacute;m nainstalovat, ale někter&eacute; funkce nemus&iacute; pracovat spr&aacute;vně.<br />Napravte pros&iacute;m situaci a klikněte  &quot;Zkusit znovu&quot; nebo klikněte na tlač&iacute;tko pokračovat.';
 $lang['install_test_passed'] = 'V&scaron;echny testy pro&scaron;ly (alespoň na minim&aacute;ln&iacute; &uacute;rovni). Klikněte pros&iacute;m na tlač&iacute;tko Pokračovat.';
-$lang['install_failed_again'] = 'Jeden nebo v&iacute;ce testů selhalo. Napravte pros&iacute;m probl&eacute;m a klikněte tlač&iacute;tko n&iacute;ze pro opakovanou kontrolu.';
+$lang['install_failed_again'] = 'Jeden nebo v&iacute;ce testů selhalo. Napravte pros&iacute;m probl&eacute;m a klikněte tlač&iacute;tko n&iacute;že pro opakovanou kontrolu.';
 $lang['install_try_again'] = 'Zkusit znovu';
 $lang['install_continue'] = 'Pokračovat';
 $lang['failure'] = 'Chyba';
@@ -226,22 +228,22 @@ $lang['test_no_dbms'] = 'Nebyla vybr&aacute;na dbms!';
 $lang['test_could_not_connect_db'] = 'Nepodařilo se připojit k datab&aacute;zi. Zkontrolujte pros&iacute;m zda uživatelsk&eacute; jm&eacute;no a heslo jsou spr&aacute;vn&eacute; a že uživatel m&aacute; opr&aacute;vněn&yacute; př&iacute;stup do t&eacute;to datab&aacute;ze.';
 $lang['test_could_not_drop_table'] = 'Nepodařilo se zahodit tabulku. Zkontrolujte zda uživatel m&aacute; pr&aacute;va na zahazov&aacute;n&iacute; tabulek v t&eacute;to datab&aacute;zi.';
 $lang['test_could_not_create_table'] = 'Nepodařilo se vytvořit tabulku. Zkontrolujte zda uživatel m&aacute; pr&aacute;va na vytv&aacute;řen&iacute; tabulek v t&eacute;to datab&aacute;zi.';
-$lang['test_check_php'] = 'Kontroluji PHP verzi 4.3+';
+$lang['test_check_php'] = 'Kontroluje se PHP verzi 4.3+';
 $lang['test_min_recommend'] = '(min %s, doporučeno %s)';
 $lang['test_min_recommend_plus'] = '(min %s, doporučeno %s+)';
 $lang['test_requires_php_version'] = 'CMS Made Simple potřebuje php verzi 4.3 a nebo vy&scaron;&scaron;&iacute; (vy m&aacute;te %s), ale PHP %s nebo vy&scaron;&scaron;&iacute; je doporučeno pro zaji&scaron;těn&iacute; maxim&aacute;ln&iacute; kompatibility s moduly třet&iacute;ch stran';
-$lang['test_check_md5_func'] = 'Kontroluji md5 funkci';
-$lang['test_check_safe_mode'] = 'Kontroluji safe mod';
+$lang['test_check_md5_func'] = 'Kontroluje se md5 funkce';
+$lang['test_check_safe_mode'] = 'Kontroluje se safe mod';
 $lang['test_check_safe_mode_failed'] = 'PHP safe mode může působit probl&eacute;m s nahr&aacute;v&aacute;n&iacute;m souborů a s někter&yacute;mi funkcemi. V&scaron;e z&aacute;lež&iacute; na tom, jak hodně striktn&iacute; je nastaven&iacute; na Va&scaron;em serveru.';
-$lang['test_check_tokenizer'] = 'Kontroluji tokenizer funkce';
+$lang['test_check_tokenizer'] = 'Kontroluj&iacute; se tokenizer funkce';
 $lang['test_check_tokenizer_failed'] = 'Bez podpory tokenizeru se může st&aacute;t, že v&scaron;echny str&aacute;nky se budou zobrazovat jako čistě b&iacute;l&eacute;. Doporučujeme, aby jste jej nainstalovali, ale Va&scaron;e str&aacute;nky můžou fungovat tak&eacute; bez něj.';
-$lang['test_check_gd'] = 'Kontroluji GD knihovnu';
+$lang['test_check_gd'] = 'Kontroluje se GD knihovna';
 $lang['test_check_gd_failed'] = 'GD knihovna je nezbytn&aacute; pro funkci někter&yacute;ch modulů.';
-$lang['test_check_write'] = 'Kontroluji pr&aacute;va z&aacute;pisu na';
+$lang['test_check_write'] = 'Kontroluj&iacute; se pr&aacute;va z&aacute;pisu na';
 $lang['test_may_not_exist'] = 'Tento soubor zat&iacute;m neexistuje. Pokud neexistuje, měli byste založit pr&aacute;zdn&yacute; soubor tohoto jm&eacute;na. Zajistěte tak&eacute;, že tento soubor bude zapisovateln&yacute; webov&yacute;m serverem.';
 $lang['could_not_retrieve_a_value'] = 'Nelze z&iacute;skat hodnotu ... přesto se pokračuje.';
 $lang['displaying_the_value_originally'] = '<br />Zobrazuje se hodnota původně nastaven&aacute; v konfiguračn&iacute;m souboru (nemus&iacute; to b&yacute;t přesn&eacute;).';
-$lang['test_check_xml_func'] = 'Kontroluji z&aacute;kladn&iacute; podporu XML (expat)';
+$lang['test_check_xml_func'] = 'Kontroluje se z&aacute;kladn&iacute; podpora XML (expat)';
 $lang['test_check_xml_failed'] = 'Podpora XML nen&iacute; zakompilov&aacute;na do Va&scaron;&iacute; instalace php. St&aacute;le můžete syst&eacute;m použ&iacute;vat, ale nebude možn&eacute; použ&iacute;vat ž&aacute;dn&eacute; funkce vzd&aacute;len&eacute; instalace modulů.';
 $lang['test_allow_url_fopen_failed'] = 'Pokud je allow url fopen zak&aacute;z&aacute;n, nebude možn&eacute; přistupovat k URL objektům jako jsou soubory přes ftp nebo http protokol.';
 $lang['test_remote_url'] = 'Test vzd&aacute;len&eacute; URL';
@@ -253,29 +255,29 @@ $lang['connection_failed'] = 'Spojen&iacute; selhalo!';
 $lang['remote_response_ok'] = 'Vzd&aacute;len&aacute; odpověď: ok!';
 $lang['remote_response_404'] = 'Vzd&aacute;len&aacute; odpověď: nenalezeno!';
 $lang['remote_response_error'] = 'Vzd&aacute;len&aacute; odpověď: chyba!';
-$lang['test_check_file_upload'] = 'Kontroluji nahr&aacute;v&aacute;n&iacute; souborů';
+$lang['test_check_file_upload'] = 'Kontroluje se nahr&aacute;v&aacute;n&iacute; souborů';
 $lang['test_check_file_failed'] = 'Když je zak&aacute;z&aacute;no nahr&aacute;v&aacute;n&iacute; souborů, nebudete moci použ&iacute;vat ž&aacute;dnou funkci nahr&aacute;v&aacute;n&iacute; souborů obsaženou v CMS Made Simple. Pokud je to možn&eacute;, toto omezen&iacute; by mělo b&yacute;t vypnuto Va&scaron;&iacute;m syst&eacute;mov&yacute;m administr&aacute;torem pro spr&aacute;vn&eacute; použit&iacute; v&scaron;ech vlastnost&iacute; spr&aacute;vy souborů v syst&eacute;mu. Pokračujte opatrně.';
-$lang['test_check_memory'] = 'Kontroluji PHP memory limit';
+$lang['test_check_memory'] = 'Kontroluje se PHP memory limit';
 $lang['test_check_memory_failed'] = 'Nem&aacute;te dostatek paměti pro spr&aacute;vn&yacute; běh CMSMS nebo v&scaron;ech požadovan&yacute;ch modulů. Pokud je to možn&eacute;, pož&aacute;dejte sv&eacute;ho syst&eacute;mov&eacute;ho administr&aacute;tora pro zv&yacute;&scaron;en&iacute; t&eacute;to hodnotu. Pokračujte opatrně.';
-$lang['test_check_time_limit'] = 'Kontroluji PHP time limit';
+$lang['test_check_time_limit'] = 'Kontroluje se PHP time limit';
 $lang['test_check_time_limit_failed'] = 'Počet vteřin pro zpracov&aacute;n&iacute; skriptu. Pokud je tato hodnota dosažena, skript vr&aacute;t&iacute; fat&aacute;ln&iacute; chybu.';
-$lang['test_check_post_max'] = 'Kontroluji maxim&aacute;ln&iacute; velikost postu';
+$lang['test_check_post_max'] = 'Kontroluje se maxim&aacute;ln&iacute; velikost postu';
 $lang['test_check_post_max_failed'] = 'Pravděpodobně nebudete moci odes&iacute;lat (vět&scaron;&iacute;) data. Uvědomte si pros&iacute;m toto omezen&iacute;.';
-$lang['test_check_upload_max'] = 'Kontroluji maxim&aacute;ln&iacute; velikost nahr&aacute;van&eacute;ho souboru';
+$lang['test_check_upload_max'] = 'Kontroluje se maxim&aacute;ln&iacute; velikost nahr&aacute;van&eacute;ho souboru';
 $lang['test_check_upload_max_failed'] = 'Pravděpodobně nebudete moci nahr&aacute;vat (vět&scaron;&iacute;) soubory přes funkci přiložen&eacute;ho spr&aacute;vce souborů. Uvědomte si pros&iacute;m toto omezen&iacute;.';
-$lang['test_check_writable'] = 'Kontroluji, zda je %s zapisovateln&eacute;';
-$lang['test_check_upload_failed'] = 'Do adres&aacute;ř uploads nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat soubory přes Administračn&iacute; panel.';
-$lang['test_check_images_failed'] = 'Do adres&aacute;ř images nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat obr&aacute;zky přes Administračn&iacute; panel.';
-$lang['test_check_modules_failed'] = 'Do adres&aacute;ř modules nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat moduly přes Administračn&iacute; panel.';
-$lang['test_check_file_get_contents'] = 'Kontroluji file_get_contents';
+$lang['test_check_writable'] = 'Kontroluje se, zda je %s zapisovateln&eacute;';
+$lang['test_check_upload_failed'] = 'Do adres&aacute;ře uploads nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat soubory přes Administračn&iacute; panel.';
+$lang['test_check_images_failed'] = 'Do adres&aacute;ře images nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat obr&aacute;zky přes Administračn&iacute; panel.';
+$lang['test_check_modules_failed'] = 'Do adres&aacute;ře modules nelze zapisovat. St&aacute;le můžete syst&eacute;m nainstalovat, ale nebudete moci nahr&aacute;vat moduly přes Administračn&iacute; panel.';
+$lang['test_check_file_get_contents'] = 'Kontroluje se file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Pravděpodobně nebudete moci použ&iacute;vat ž&aacute;dnou funkcionalitu využ&iacute;vaj&iacute;c&iacute; tuto funkci';
-$lang['test_check_session_save_path'] = 'Kontroluji, zda je session.save_path zaposovateln&eacute;';
+$lang['test_check_session_save_path'] = 'Kontroluje se, zda je session.save_path zaposovateln&eacute;';
 $lang['test_empty_session_save_path'] = 'Va&scaron;e session.save_path je pr&aacute;zdn&aacute;. PHP bude použ&iacute;vat dočasn&yacute; adres&aacute;ř Va&scaron;eho OS. Pokud budete m&iacute;t prob&eacute;my se SESSION a ini_set pracuje, můžete zkusit nastavit session přes cookies vložen&iacute;m: ini_set(&#039;session.use_only_cookies&#039;, 1);  na zač&aacute;tek souboru include.php';
 $lang['test_check_session_save_path_failed'] = 'Va&scaron;e session.save_path je &quot;%s&quot;. Pokud tam nejde zapisovat, nemus&iacute; b&yacute;t funkčn&iacute; přihla&scaron;ov&aacute;n&iacute; do Administračn&iacute;ho panelu. Pokud tomu tak bude, je třeba tuto cestu nastavit zapisovatelnou. Tento test tak&eacute; selže, pokud je povolen safe mod (viz. n&iacute;že).';
-$lang['test_check_ini_set'] = 'Kontrola, zda je mono použ&iacute;vat ini_set';
+$lang['test_check_ini_set'] = 'Kontroluje se, zda je možn&eacute; použ&iacute;vat ini_set';
 $lang['test_check_ini_set_failed'] = 'Ačkoliv možnost měnit nastaven&iacute; v souboru php.ini nen&iacute; povinn&aacute;, někter&aacute; roz&scaron;&iacute;řen&iacute; mohou tato nastaven&iacute; potřebovat (např. pro možnost nahr&aacute;vat vět&scaron;&iacute; soubory). Tento test může selhat, pokud je povolen safe_mode v php.';
 $lang['install_admin_header'] = 'Informace o administr&aacute;torsk&eacute;m &uacute;čtu';
-$lang['install_admin_info'] = 'Vyberte uživatelsk&eacute; jm&eacute;no, heslo a e-mailovou adresu pro V&aacute;&scaron; administr&aacute;torsk&yacute; &uacute;čet. Tyto &uacute;daje si pros&iacute;m poznamenejte, bez nich se nen&iacute; možno přihl&aacute;sit do administračn&iacute;ho rozhran&iacute;.';
+$lang['install_admin_info'] = 'Vyberte uživatelsk&eacute; jm&eacute;no, heslo a emailovou adresu pro V&aacute;&scaron; administr&aacute;torsk&yacute; &uacute;čet. Tyto &uacute;daje si pros&iacute;m poznamenejte, bez nich se nen&iacute; možno přihl&aacute;sit do administračn&iacute;ho rozhran&iacute;.';
 $lang['install_admin_email'] = 'E-mailov&aacute; adresa';
 $lang['install_admin_email_info'] = 'Odeslat informace o vytv&aacute;řen&eacute;m &uacute;čtu e-mailem.';
 $lang['install_admin_email_note'] = '<strong>Pozn&aacute;mka:</strong> Tato funkce použ&iacute;v&aacute; funkci mail v php. Pokud neobdrž&iacute;te tento e-mail, může to znamenat, že server nen&iacute; spr&aacute;vně nakonfigurov&aacute;n a měli byste kontaktovat administr&aacute;tora (podporu) hostingu.';
@@ -298,28 +300,28 @@ $lang['install_admin_db_create'] = 'Vytvořit tabulky (Varov&aacute;n&iacute;: V
 $lang['install_admin_db_prefix'] = 'Prefix tabulky';
 $lang['install_admin_db_sample'] = 'Instalovat vzorek dat a &scaron;ablon';
 $lang['retry'] = 'Znovu';
-$lang['install_admin_db_create_seq'] = 'Vytv&aacute;ř&iacute;m  %s table sequence...';
-$lang['install_admin_importing'] = 'Importuji vzorek dat...';
+$lang['install_admin_db_create_seq'] = 'Vytv&aacute;ř&iacute; se %s table sequence...';
+$lang['install_admin_importing'] = 'Importuje se vzorek dat...';
 $lang['invalid_query'] = 'Chybn&yacute; dotaz: %s';
-$lang['install_creating_table'] = '<p>Vytv&aacute;ř&iacute;m tabulku %s...';
+$lang['install_creating_table'] = '<p>Vytv&aacute;ř&iacute; se tabulka %s...';
 $lang['install_creating_index'] = '<p>Vytv&aacute;ř&iacute; se index v tabulce %s... [%s]</p>';
 $lang['done'] = 'hotovo';
 $lang['failed'] = 'selhalo';
 $lang['install_admin_error_schema'] = 'Chyba při vyzved&aacute;v&aacute;n&iacute; SQL sch&eacute;matu';
-$lang['install_admin_set_account'] = 'Nastavuji &uacute;čet administr&aacute;tora...';
-$lang['install_admin_set_sitename'] = 'Nastavuji jm&eacute;no str&aacute;nek...';
+$lang['install_admin_set_account'] = 'Nastavuje se &uacute;čet administr&aacute;tora...';
+$lang['install_admin_set_sitename'] = 'Nastavuje se jm&eacute;no str&aacute;nek...';
 $lang['install_admin_setup'] = 'Nyn&iacute; bude pokračovat nastaven&iacute; konfiguračn&iacute;ho souboru, mnoho potřebn&yacute;ch věc&iacute; už je hotov&yacute;ch. Možnost je nechat v&scaron;echny tyto hodnoty jak jsou, stač&iacute; kliknout na Pokračovat.';
 $lang['install_admin_docroot'] = 'CMS Document root (z pohledu webserveru)';
 $lang['install_admin_docroot_path'] = 'Cesta k Document rootu';
 $lang['install_admin_querystring'] = 'Řetězec dotazu (ponechte toto pole beze změny pokud v&scaron;e funguje spr&aacute;vně, později můžete nastavit v souboru config.php)';
-$lang['invalid_querys'] = '<b>VAROV&Aacute;N&Iacute;<b/>: Invalidn&iacute; dotazy na datab&aacute;zi!';
+$lang['invalid_querys'] = '<b>VAROV&Aacute;N&Iacute;<b/>: Nespr&aacute;vn&eacute; dotazy na datab&aacute;zi!';
 $lang['install_admin_sitedown'] = 'Chyba: Nemohu odebrat soubor tmp/cache/SITEDOWN. Pros&iacute;m odeberte soubor ručně.';
-$lang['install_admin_update_hierarchy'] = 'Aktualizuji hierarchick&eacute; pozice...';
-$lang['install_admin_set_core_event'] = 'Nastavuji ud&aacute;losti j&aacute;dra...';
-$lang['install_admin_install_modules'] = 'Instaluji moduly...';
-$lang['install_admin_index_search'] = 'Vytv&aacute;ř&iacute;m index pro hled&aacute;n&iacute;...';
-$lang['install_admin_clear_cache'] = 'Čist&iacute;m cache str&aacute;nek (pokud existuje)...';
-$lang['install_admin_emailing'] = 'Odes&iacute;l&aacute;m informace o administr&aacute;torsk&eacute;m &uacute;čtu e-mailem...';
+$lang['install_admin_update_hierarchy'] = 'Aktualizuj&iacute; se hierarchick&eacute; pozice...';
+$lang['install_admin_set_core_event'] = 'Nastavuj&iacute; se ud&aacute;losti j&aacute;dra...';
+$lang['install_admin_install_modules'] = 'Instaluj&iacute; se moduly...';
+$lang['install_admin_index_search'] = 'Vytv&aacute;ř&iacute; se index pro hled&aacute;n&iacute;...';
+$lang['install_admin_clear_cache'] = 'Čist&iacute; se cache str&aacute;nek (pokud existuje)...';
+$lang['install_admin_emailing'] = 'Odes&iacute;laj&iacute; se informace o administr&aacute;torsk&eacute;m &uacute;čtu e-mailem...';
 $lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;echna nastaven&iacute; byla provedena - zde je va&scaron;e <a href="%s">nov&aacute; str&aacute;nka</a>';
 $lang['could_not_connect_db'] = 'Nelze se připojit do datab&aacute;ze. Ověřte pros&iacute;m spr&aacute;vnost uživatelsk&eacute;ho jm&eacute;na a hesla, a opr&aacute;vněn&iacute; uživatele přistupovat k dan&eacute; datab&aacute;zi.';
 $lang['cannot_write_config'] = 'Chyba: Nelze zapisovat do %s.';
@@ -330,9 +332,9 @@ Informace o Va&scaron;em nov&eacute;m &uacute;čtu:
 uživatelsk&eacute; jm&eacute;no: %s
 heslo: %s
 
-Přihl&aacute;&scaron;en&iacute; do administrace zde: %s';
-$lang['utma'] = '156861353.4545864025444168000.1227726513.1235876853.1235894120.23';
-$lang['utmz'] = '156861353.1235854022.19.6.utmccn=(referral)|utmcsr=miditower|utmcct=/cms/admin/listmodules.php|utmcmd=referral';
-$lang['utmc'] = '156861353';
+Přihl&aacute;sit do administrace se můžete zde: %s';
+$lang['utma'] = '156861353.503654010.1232181160.1241440658.1245245150.32';
+$lang['utmz'] = '156861353.1245245150.32.7.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/projects/czech|utmcmd=referral';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
