@@ -53,7 +53,7 @@ $lang['is_readable_false'] = 'Die angegebene Quelle konnte nicht gelesen werden!
 $lang['checksum_match'] = 'Die Pr&uuml;fsumme stimmt &uuml;berein!';
 $lang['checksum_not_match'] = 'Die Pr&uuml;fsumme stimmt NICHT &uuml;berein!';
 $lang['not_checksum'] = 'Konnte keine Pr&uuml;fsumme erstellen!';
-$lang['format_datetime'] = '%c';
+$lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Die hochgeladene Datei ist gr&ouml;&szlig;er als der Wert (upload_max_filesize), der nach Ihrer php.ini erlaubt ist!';
 $lang['upload_err_form_size'] = 'Die hochgeladene Datei ist gr&ouml;&szlig;er als der Wert (MAX_FILE_SIZE), der f&uuml;r HTML-Formulare festgelegt wurde.';
 $lang['upload_err_partial'] = 'Die Datei wurde nur teilweise hochgeladen.';
@@ -167,7 +167,7 @@ $lang['filesize'] = 'Dateigr&ouml;&szlig;e';
 $lang['help'] = 'Hilfe';
 $lang['language'] = 'Sprache';
 $lang['lastname'] = 'Nachname';
-$lang['name'] = 'Name';
+$lang['name'] = 'Name ';
 $lang['password'] = 'Passwort';
 $lang['passwordagain'] = 'Passwort (nochmals)';
 $lang['remove'] = 'Entfernen';
@@ -182,7 +182,7 @@ $lang['userdefinedtags'] = 'Benutzerdefinierte Tags';
 $lang['usermanagement'] = 'Benutzerverwaltung';
 $lang['username'] = 'Benutzername';
 $lang['usernameincorrect'] = 'Benutzername oder Passwort sind falsch';
-$lang['version'] = 'Version';
+$lang['version'] = 'Version ';
 $lang['install_title'] = 'CMS Made Simple - Installation - Schritt %s';
 $lang['install_system'] = 'Installations-System';
 $lang['install_thanks'] = 'Vielen Dank f&uuml;r die Installation von CMS made simple';
@@ -197,7 +197,7 @@ $lang['install_required_settings'] = 'Erforderliche Einstellungen';
 $lang['install_recommended_settings'] = 'Empfohlene Einstellungen';
 $lang['install_you_have'] = 'Ihre Einstellung';
 $lang['install_legend'] = 'Legende';
-$lang['install_symbol'] = 'Symbol';
+$lang['install_symbol'] = 'Symbol ';
 $lang['install_definition'] = 'Erkl&auml;rung';
 $lang['install_value_passed'] = 'Dieser Test wurde bestanden';
 $lang['install_value_failed'] = 'Dieser Test wurde nicht bestanden';
@@ -332,8 +332,9 @@ Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['utma'] = '156861353.717462736.1147511856.1249117058.1249133074.380';
-$lang['utmz'] = '156861353.1245564627.365.3.utmccn=(referral)|utmcsr=just4test.de|utmcct=/amiga/listmodules.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-1909116003-1254132235568';
+$lang['utma'] = '156861353.858097627.1254132339.1254132339.1254136190.2';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1254136190.2.2.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
