@@ -12,12 +12,12 @@ $lang['test_check_db_drivers_failed'] = 'Aucun drivers DB trouv&eacute;';
 $lang['test_check_register_globals'] = 'V&eacute;rification PHP register globals';
 $lang['test_check_register_globals_failed'] = 'PHP register_globals actif. Pour des raisons de s&eacute;curit&eacute;, d&eacute;sactiver cette option.';
 $lang['test_check_disable_functions'] = 'V&eacute;rification des fonctions PHP d&eacute;sactiv&eacute;es';
-$lang['test_check_disable_functions_failed'] = 'Attention : Ceci est une liste des fonctions d&eacute;sactiv&eacute;es sur votre serveur.';
+$lang['test_check_disable_functions_failed'] = 'Attention : ceci est une liste des fonctions d&eacute;sactiv&eacute;es sur votre serveur.';
 $lang['install_admin_db_port'] = 'Port de Base de Donn&eacute;es';
-$lang['install_admin_db_port_info'] = 'Laisser ce champ vide pour avoir le port de BD par d&eacute;faut';
+$lang['install_admin_db_port_info'] = 'Laissez ce champ vide pour avoir le port de BD par d&eacute;faut';
 $lang['install_admin_db_socket'] = 'Socket de Base de Donn&eacute;es';
 $lang['install_admin_db_socket_info'] = 'NON support&eacute;.';
-$lang['install_admin_frontendlang'] = 'Langue par d&eacute;faut pour l&#039;interface publique. Locale &agrave; utiliser par d&eacute;faut pour diverses fonctions de manipulation de la date, etc... Laisser ce champ vide pour un environnement multilangue ou utiliser les valeurs par d&eacute;faut du serveur';
+$lang['install_admin_frontendlang'] = 'Langue par d&eacute;faut pour l&#039;interface publique. Locale &agrave; utiliser par d&eacute;faut pour diverses fonctions de manipulation de la date, etc... Laisser ce champ vide pour un environnement multilingue ou utiliser les valeurs par d&eacute;faut du serveur';
 $lang['install_default_encoding'] = 'Dans presque tous les cas, utf-8 devrait &ecirc;tre l&#039;encodage. Si vous vous voulez un encodage diff&eacute;rent, changez ici, mais gardez &agrave; l&#039;esprit, cependant, que toutes les traductions de langues sont en utf-8';
 $lang['installer_done'] = '[fait]';
 $lang['installer_failed'] = '[&eacute;chec]';
@@ -46,7 +46,7 @@ $lang['upgrade_end'] = 'CMSMS est &agrave; jour. Cliquez %s pour aller sur votre
 $lang['here'] = 'ici';
 $lang['go_to_admin'] = 'Administration';
 $lang['errorfilenot'] = 'Fichier non trouv&eacute; !';
-$lang['errorfilenotwritable'] = 'Le fichier n&#039;a pas de permissions en &eacute;criture';
+$lang['errorfilenotwritable'] = 'Le fichier n&#039;a pas de permission en &eacute;criture';
 $lang['nofiles'] = 'Cette ressource n&#039;existe pas !';
 $lang['is_directory'] = 'Cette ressource est un dossier !';
 $lang['is_readable_false'] = 'Cette ressource n&#039;a pas les permissions de lecture !';
@@ -67,9 +67,9 @@ $lang['function_file_uploads_off'] = 'file_uploads est d&eacute;sactiv&eacute; d
 $lang['upload_file_no_readable'] = 'Fichier upload&eacute; non lisible !';
 $lang['upload_file_multiple'] = 'Les uploads multiples ne sont pas autoris&eacute;s !';
 $lang['test_check_magic_quotes_gpc'] = 'V&eacute;rification de &quot;magic_quotes&quot; pour les op&eacute;rations Get/Post/Cookie';
-$lang['test_check_magic_quotes_gpc_failed'] = 'Lorsque les magic_quotes sont &agrave; &quot;On&quot;, les guillemets simples, doubles et antislash sont &eacute;chapp&eacute;s avec un antislash automatiquement. Vous pouvez avoir des probl&egrave;mes avec les gabarits.';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, les guillemets simples, doubles et antislash sont &eacute;chapp&eacute;s avec un antislash automatiquement. Vous pouvez avoir des probl&egrave;mes avec les gabarits.';
 $lang['test_check_magic_quotes_runtime'] = 'V&eacute;rification de magic_quotes_runtime';
-$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les magic_quotes sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Lorsque les &quot;magic_quotes&quot; sont &agrave; &quot;On&quot;, la plupart des fonctions qui retournent des donn&eacute;es externes, comme ceux des bases de donn&eacute;es ou des fichiers texte, auront &eacute;t&eacute; &eacute;chapp&eacute; avec un anti-slash. Vous pouvez avoir des probl&egrave;mes.';
 $lang['install_admin_checksum'] = 'V&eacute;rification de votre installation';
 $lang['upgrade_admin_checksum'] = 'V&eacute;rification de votre installation avant mise &agrave; jour';
 $lang['checksum'] = 'Test de contr&ocirc;le (checksum)';
@@ -119,7 +119,7 @@ $lang['help_systeminformation'] = 'Les informations affich&eacute;es ci-dessous
 $lang['systeminfo'] = 'Informations syst&egrave;me';
 $lang['systeminfodescription'] = 'Affiche diff&eacute;rentes informations sur votre syst&egrave;me pour aider &agrave; diagnostiquer des probl&egrave;mes.';
 $lang['error'] = 'Erreur';
-$lang['new_version_available'] = '<em>Remarque :</em> Une nouvelle version de CMS Made Simple est disponible. Informez-en votre administrateur.';
+$lang['new_version_available'] = '<em>Remarque :</em> une nouvelle version de CMS Made Simple est disponible. Informez-en votre administrateur.';
 $lang['info_urlcheckversion'] = 'Si cette URL utilise le mot &quot;none&quot;, aucun contr&ocirc;le ne sera effectu&eacute;.<br/>Une cha&icirc;ne vide utilisera l&#039;URL par d&eacute;faut.';
 $lang['urlcheckversion'] = 'V&eacute;rifier les nouvelles versions CMS &agrave; l&#039;aide de cette URL&nbsp;';
 $lang['read'] = 'Lecture';
@@ -158,7 +158,7 @@ $lang['edit'] = 'Editer';
 $lang['email'] = 'Addresse email';
 $lang['errordeletingfile'] = 'Impossible de supprimer le fichier. (probl&egrave;me de permissions ?)';
 $lang['errordirectorynotwritable'] = 'Aucune autorisation d&#039;&eacute;crire dans le dossier. Cela pourrait &ecirc;tre caus&eacute; par les permissions de fichiers. Le safe_mode de PHP peut causer des difficult&eacute;s.';
-$lang['cachenotwritable'] = 'Le dossier /tmp/cache n&#039;a pas de permissions en &eacute;criture. L&#039;effacement du cache ne fonctionnera pas. Mettre Le dossier /tmp/cache avec des droits de lecture/&eacute;criture/ex&eacute;cution (chmod 777 ou 755 ou 775 suivant h&eacute;bergement). Il est &eacute;galement possible de devoir d&eacute;sactiver le safe_mode.';
+$lang['cachenotwritable'] = 'Le dossier /tmp/cache n&#039;a pas de permissions en &eacute;criture. L&#039;effacement du cache ne fonctionnera pas. Mettre Le dossier /tmp/cache avec des droits de lecture/&eacute;criture/ex&eacute;cution (chmod 777 ou 755 ou 775 suivant h&eacute;bergement). Il est &eacute;galement possible de d&eacute;sactiver le safe_mode.';
 $lang['modulesnotwritable'] = 'Le dossier /modules n&#039;a pas de permissions en &eacute;criture. Si vous souhaitez installer des modules en t&eacute;l&eacute;chargeant un fichier XML, vous devez donner au dossier /modules des droits de lecture/ &eacute;criture/ex&eacute;cution (chmod 777 ou 755 ou 775 suivant h&eacute;bergement). Le safe_mode de PHP peut causer des difficult&eacute;s.';
 $lang['false'] = 'Faux';
 $lang['settrue'] = 'Mettre &agrave; Vrai';
@@ -291,7 +291,7 @@ $lang['install_admin_db_info'] = '<p><strong>Connectez-vous &agrave; MySQL depui
 <p><strong>Ou utiliser un programme comme PhpMyAdmin ou le panneau d&#039;administration de votre compte.</strong></p>';
 $lang['install_admin_follow'] = 'Merci de compl&eacute;ter les champs suivants&nbsp;';
 $lang['install_admin_db_type'] = 'Type de base de donn&eacute;es';
-$lang['install_admin_no_db'] = 'Il n&#039;existe pas de divers de base de donn&eacute;es valide compil&eacute;e dans votre installation de PHP. Merci de confirmer que vous avez mysql, mysqli, et/ou postgres7 d&#039;install&eacute;, et essayer &agrave; nouveau.';
+$lang['install_admin_no_db'] = 'Il n&#039;existe pas de drivers de base de donn&eacute;es valide compil&eacute;e dans votre installation de PHP. Merci de confirmer que vous avez mysql, mysqli, et/ou postgres7 d&#039;install&eacute;, et essayez &agrave; nouveau.';
 $lang['install_admin_db_host'] = 'Adresse du serveur de base de donn&eacute;es';
 $lang['install_admin_db_name'] = 'Nom de la base de donn&eacute;es';
 $lang['install_admin_db_create'] = 'Cr&eacute;ation des tables - Ne pas cocher si mise &agrave; jour <br />(Attention : Suppression des donn&eacute;es existantes)';
@@ -299,7 +299,7 @@ $lang['install_admin_db_prefix'] = 'Pr&eacute;fixe des tables';
 $lang['install_admin_db_sample'] = 'Installer les exemples de contenus et les gabarits';
 $lang['retry'] = 'Nouvel essai';
 $lang['install_admin_db_create_seq'] = 'Cr&eacute;ation %s s&eacute;quences des tables ...&nbsp;';
-$lang['install_admin_importing'] = 'Import de sample data ...&nbsp;';
+$lang['install_admin_importing'] = 'Import des exemples de donn&eacute;es ...&nbsp;';
 $lang['invalid_query'] = 'Requ&ecirc;te invalide : %s';
 $lang['install_creating_table'] = '<p>Cr&eacute;ation table %s ... [%s]</p>';
 $lang['install_creating_index'] = '<p>Cr&eacute;ation index de table %s  ... [%s]</p>';
@@ -308,20 +308,20 @@ $lang['failed'] = '&eacute;chec';
 $lang['install_admin_error_schema'] = 'Erreur dans le sch&eacute;ma SQL';
 $lang['install_admin_set_account'] = 'Configuration des informations administration ...&nbsp;';
 $lang['install_admin_set_sitename'] = 'Configuration du nom de votre Site ...&nbsp;';
-$lang['install_admin_setup'] = 'Continuez maintenant l&#039;installation de votre fichier de configuration, avec les donn&eacute;es recueillies. Quand vous &ecirc;tes pr&ecirc;t, cliquer sur le bouton Continuer.';
-$lang['install_admin_docroot'] = 'La racine de CMS (Adresse du site web)';
-$lang['install_admin_docroot_path'] = 'Chemin de la racine de CMS';
-$lang['install_admin_querystring'] = 'Symbole apr&egrave;s &quot;index.php?&quot; (exemple. http://www.mysite.com/index.php?page=xxx ). Laisser tel quel et &eacute;ventuellement &eacute;diter le fichier config.php &agrave; la main';
-$lang['invalid_querys'] = '<b>ATTENTION<b/> : Requ&ecirc;te invalide sur la base de donn&eacute;es !';
+$lang['install_admin_setup'] = 'Continuez maintenant l&#039;installation de votre fichier de configuration, avec les donn&eacute;es recueillies. Quand vous &ecirc;tes pr&ecirc;t, cliquez sur le bouton Continuer.';
+$lang['install_admin_docroot'] = 'La racine du CMS (Adresse du site web)';
+$lang['install_admin_docroot_path'] = 'Chemin de la racine du CMS';
+$lang['install_admin_querystring'] = 'Symbole apr&egrave;s &quot;index.php?&quot; (exemple. http://www.monsite.fr/index.php?page=xxx ). Laissez tel quel et &eacute;ventuellement &eacute;ditez le fichier config.php &agrave; la main';
+$lang['invalid_querys'] = '<b>ATTENTION<b/> : requ&ecirc;te invalide sur la base de donn&eacute;es !';
 $lang['install_admin_sitedown'] = 'Erreur : Impossible de supprimer le fichier tmp/cache/SITEDOWN. Merci de le supprimer manuellement.';
 $lang['install_admin_update_hierarchy'] = 'Mise &agrave; jour de la hi&eacute;rarchie ...&nbsp;';
 $lang['install_admin_set_core_event'] = 'Configuration du noyau CMS Made Simple ...&nbsp;';
 $lang['install_admin_install_modules'] = 'Installation des modules ...&nbsp;';
 $lang['install_admin_index_search'] = 'Recherche de l&#039;index...&nbsp;';
-$lang['install_admin_clear_cache'] = 'Effacement du cache (Si besoin) ...&nbsp;';
+$lang['install_admin_clear_cache'] = 'Effacement du cache (si besoin) ...&nbsp;';
 $lang['install_admin_emailing'] = 'Mail d&#039;information sur le compte Administrateur cr&eacute;&eacute; ...&nbsp;';
 $lang['install_admin_congratulations'] = 'Merci pour l&#039;installation de CMS Made Simple, la configuration est termin&eacute;e - Se connecter sur&nbsp; ';
-$lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifier que le Nom d&#039;utilisateur et/ou le mot de passe soit correct, et que les acc&egrave;s soit autoris&eacute;s pour l&#039;utilisateur.';
+$lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifiez que le nom d&#039;utilisateur et/ou le mot de passe sont correct, et que les acc&egrave;s sont autoris&eacute;s pour l&#039;utilisateur.';
 $lang['cannot_write_config'] = 'Erreur : Impossible d&#039;&eacute;crire sur %s.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple - Information sur le compte administrateur';
 $lang['email_accountinfo_message'] = 'Merci d&#039;avoir install&eacute; CMS Made Simple.
@@ -331,8 +331,9 @@ Nom utilisateur : %s
 Mot de passe : %s
 
 Se connecter &agrave; l&#039;administration : %s';
-$lang['utma'] = '156861353.3775108633884901000.1235391363.1248695048.1248703322.12';
-$lang['utmz'] = '156861353.1248703322.12.5.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,18160.msg169903.html';
-$lang['qca'] = '1190056125-857062-80953967';
-$lang['qcb'] = '152686946';
+$lang['utma'] = '156861353.3936683226868494000.1247055583.1253172677.1253192380.57';
+$lang['utmz'] = '156861353.1253192380.57.28.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/feature_request/list/740|utmcmd=referral';
+$lang['qca'] = '1246563679-91537581-2740096';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
