@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: content.functions.php 4956 2008-08-24 16:30:30Z calguy1000 $
+#$Id: content.functions.php 5669 2009-05-07 17:27:44Z calguy1000 $
 
 /**
  * Handles content related functions
@@ -76,7 +76,7 @@ class Smarty_CMS extends Smarty {
 			$this->debugging = true;
 		}
 
-		if (get_site_preference('enablesitedownmessage') == "1")
+		if (is_sitedown())
 		{
 			$this->caching = false;
 			$this->force_compile = true;
@@ -122,10 +122,6 @@ class Smarty_CMS extends Smarty {
 						       "global_content_get_timestamp",
 						       "db_get_secure",
 						       "db_get_trusted"));
-		$this->register_resource("preview", array(&$this, "preview_get_template",
-						       "preview_get_timestamp",
-						       "db_get_secure",
-						       "db_get_trusted"));
 		$this->register_resource("content", array(&$this, "content_get_template",
 						       "content_get_timestamp",
 						       "db_get_secure",
@@ -218,7 +214,8 @@ class Smarty_CMS extends Smarty {
 
 		$db = &$gCms->GetDb();
 		$config = $gCms->config;
-		if( isset($gCms->variables['module_template_cache']) )
+		if( isset($gCms->variables['module_template_cache']) &&
+		    isset($gCms->variables['module_template_cache'][$tpl_name]) )
 		  {
 		    $tpl_timestamp = $gCms->variables['module_template_cache'][$tpl_name];
 		    return true;
@@ -230,12 +227,17 @@ class Smarty_CMS extends Smarty {
 
 		if( !count($results) ) return false;
 
-		$tmp = array();
+		if( !isset($gCms->variables['module_template_cache']) )
+		  {
+		    $gCms->variables['module_template_cache'] = array();
+		  }
 		foreach( $results as $row )
 		  {
-		    $tmp[$row['module_name'].';'.$row['template_name']] = $db->UnixTimeStamp($row['modified_date']);
+		    $key = $row['module_name'].';'.$row['template_name'];
+		    $val = $db->UnixTimeStamp($row['modified_date']);
+		    $gCms->variables['module_template_cache'][$key] = $val;
 		  }
-		$gCms->variables['module_template_cache'] = $tmp;
+
 		$tpl_timestamp = $gCms->variables['module_template_cache'][$tpl_name];
 		return true;
 	}
@@ -301,119 +303,12 @@ class Smarty_CMS extends Smarty {
 		}
 	}
 
-	function preview_get_template ($tpl_name, &$tpl_source, &$smarty_obj)
-	{
-		global $gCms;
-		$config = $gCms->config;
-
-		$fname = '';
-		if (is_writable($config["previews_path"]))
-		{
-			$fname = cms_join_path($config["previews_path"] , $tpl_name);
-		}
-		else
-		{
-			$fname = cms_join_path(TMP_CACHE_LOCATION , $tpl_name);
-		}
-		if (true == file_exists($fname))
-		{
-			$handle = fopen($fname, "r");
-			$data = unserialize(fread($handle, filesize($fname)));
-			fclose($handle);
-			unlink($fname);
-	
-			$tpl_source = $data["template"];
-		}
-		else
-		{
-			$tpl_source = 'Error: Cache file: '.$tpl_name.' does not exist.';
-		}
-		#Perform the content template callback
-		reset($gCms->modules);
-		while (list($key) = each($gCms->modules))
-		{
-			$value =& $gCms->modules[$key];
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				$gCms->modules[$key]['object']->ContentTemplate($tpl_source);
-			}
-		}
-		
-		Events::SendEvent('Core', 'ContentTemplate', array('template' => &$tpl_source));
-
-		$gCms->variables['page'] = $data['content_id'];
-		$gCms->variables['page_id'] = $data['content_id'];
-		$gCms->variables['content_id'] = $data['content_id'];
-		$gCms->variables['page_name'] = $data['title'];
-		$gCms->variables['position'] = $data['hierarchy'];
-		$pageinfo = new StdClass();
-		$pageinfo->template_id =  $data['template_id'];
-		$pageinfo->content_title = $data['title'];
-		$gCms->variables['pageinfo'] = $pageinfo;
-		header("Content-Type: text/html; charset=" . (isset($data['encoding']) && $data['encoding'] != ''?$data['encoding']:get_encoding()));
-
-		$content = $data["content"];
-		 
-		reset($gCms->modules);
-		while (list($key) = each($gCms->modules))
-		{
-			$value =& $gCms->modules[$key];
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				$gCms->modules[$key]['object']->ContentPreCompile($content);
-			}
-		}
-		
-		Events::SendEvent('Core', 'ContentPreCompile', array('content' => &$content));
-
-		$tpl_source = eregi_replace("\{content\}", $content, $tpl_source);
-
-		$title = $data['title'];
-		$menutext = $data['menutext'];
-
-		#Perform the content title callback
-		/*
-		reset($gCms->modules);
-		while (list($key) = each($gCms->modules))
-		{
-			$value =& $gCms->modules[$key];
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				$gCms->modules[$key]['object']->ContentTitle($title);
-			}
-		}
-		*/
-
-		$tpl_source = ereg_replace("\{title\}", $title, $tpl_source);
-		$tpl_source = ereg_replace("\{menutext\}", $menutext, $tpl_source);
-
-		#So no one can do anything nasty, take out the php smarty tags.  Use a user
-		#defined plugin instead.
-		if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
-		{
-			$tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
-		}
-
-		return true;
-	}
-
-
-	function preview_get_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
-	{
-		$tpl_timestamp = time();
-		return true;
-	}
-
-
 	function template_top_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
 	  $config =& $gCms->GetConfig();
 	  
-	  if (get_site_preference('enablesitedownmessage') == "1")
+	  if (is_sitedown())
 	    {
 	      $tpl_source = '';
 	      return true;
@@ -459,7 +354,7 @@ class Smarty_CMS extends Smarty {
 	  global $gCms;
 	  $config =& $gCms->GetConfig();
 	  
-	  if (get_site_preference('enablesitedownmessage') == "1")
+	  if (is_sitedown())
 	    {
 	      $tpl_source = '';
 	      return true;
@@ -509,7 +404,7 @@ class Smarty_CMS extends Smarty {
 	  global $gCms;
 	  $config =& $gCms->GetConfig();
 	  
-	  if (get_site_preference('enablesitedownmessage') == "1")
+	  if (is_sitedown())
 	    {
 	      header('HTTP/1.0 503 Service Unavailable');
 	      header('Status: 503 Service Unavailable');
@@ -563,7 +458,7 @@ class Smarty_CMS extends Smarty {
 		global $gCms;
 		$config =& $gCms->GetConfig();
 
-		if (get_site_preference('enablesitedownmessage') == "1")
+		if (is_sitedown())
 		{
 			$tpl_source = get_site_preference('sitedownmessage');
 			return true;
@@ -580,6 +475,7 @@ class Smarty_CMS extends Smarty {
 			}
 			else if (isset($_GET["print"]))
 			{
+			  // this should really just go.
 				$script = '';
 
 				if (isset($_GET["js"]) and $_GET["js"] == 1)
@@ -592,7 +488,7 @@ class Smarty_CMS extends Smarty {
 				else
 				{
 				  $hm =& $gCms->GetHierarchyManager();
-				  if (true == $config['assume_mod_rewrite'])
+				  if ('mod_rewrite' == $config['url_rewriting'])
 				    {
 				      $curnode =& $hm->getNodeByAlias($tpl_name);
 				    }
@@ -608,6 +504,38 @@ class Smarty_CMS extends Smarty {
 
 				return true;
 			}
+			if( isset($_SESSION['cms_preview']) )
+			  {
+			    return 'DEBUG: IN PREVIEW<br/>';
+
+			    // get serialized data filename
+			    $tpl_name = trim($_SESSION['cms_preview']);
+			    unset($_SESSION['cms_preview']);
+			    $fname = '';
+			    if (is_writable($config["previews_path"]))
+			      {
+				$fname = cms_join_path($config["previews_path"] , $tpl_name);
+			      }
+			    else
+			      {
+				$fname = cms_join_path(TMP_CACHE_LOCATION , $tpl_name);
+			      }
+			    if( !file_exists($fname) )
+			      {
+				$tpl_source = 'Error: Cache file: '.$tpl_name.' does not exist.';
+				return false;
+			      }
+
+			    // get the serialized data
+			    $handle = fopen($fname, "r");
+			    $data = unserialize(fread($handle, filesize($fname)));
+			    fclose($handle);
+			    unlink($fname);
+	
+			    $tpl_source = $data["template"];
+
+			    return true;
+			  }
 			else
 			{
 				global $gCms;
@@ -637,7 +565,7 @@ class Smarty_CMS extends Smarty {
 	{
 		global $gCms;
 
-		if (get_site_preference('enablesitedownmessage') == "1" || $tpl_name == 'notemplate')
+		if (is_sitedown() || $tpl_name == 'notemplate')
 		{
 			$tpl_timestamp = time();
 			return true;
@@ -678,6 +606,26 @@ class Smarty_CMS extends Smarty {
 				$tpl_source = '';
 			return true;
 		}
+		else if( isset($_SESSION['cms_preview_data']) && $pageinfo->content_id == '__CMS_PREVIEW_PAGE__' )
+	        {
+		  if( !isset($_SESSION['cms_preview_data']['content_obj']) )
+		    {
+		      $contentops =& $gCms->GetContentOperations();
+		      $_SESSION['cms_preview_data']['content_obj'] = $contentops->LoadContentFromSerializedData($_SESSION['cms_preview_data']);
+		      $contentobj =& $_SESSION['cms_preview_data']['content_obj'];
+		    }
+		  $contentobj =& $_SESSION['cms_preview_data']['content_obj'];
+		  $tpl_source = $contentobj->Show($tpl_name);
+
+                  #So no one can do anything nasty, take out the php smarty tags.  Use a user
+                  #defined plugin instead.
+		  if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
+		    {
+		      $tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+		    }
+
+		  return true;
+		}
 		else
 		{
 			$manager =& $gCms->GetHierarchyManager();
@@ -686,43 +634,9 @@ class Smarty_CMS extends Smarty {
 
 			if (isset($contentobj) && $contentobj !== FALSE)
 			{
-				if ($tpl_name != 'content_en')
-				{
-					//TODO: Fix Me.  This is a super hack.
-					$contentobj->GetAdditionalContentBlocks();
-				}
 
 				$tpl_source = $contentobj->Show($tpl_name);
 
-				#Perform the content data callback
-				#This needs to go...
-				/*
-				reset($gCms->modules);
-				while (list($key) = each($gCms->modules))
-				{
-					$value =& $gCms->modules[$key];
-					if ($gCms->modules[$key]['installed'] == true &&
-						$gCms->modules[$key]['active'] == true)
-					{
-						$gCms->modules[$key]['object']->ContentData($tpl_source);
-					}
-				}
-				*/
-
-				#Perform the content prerender callback
-				/*
-				reset($gCms->modules);
-				while (list($key) = each($gCms->modules))
-				{
-					$value =& $gCms->modules[$key];
-					if ($gCms->modules[$key]['installed'] == true &&
-						$gCms->modules[$key]['active'] == true)
-					{
-						$gCms->modules[$key]['object']->ContentPreRender($tpl_source);
-					}
-				}
-				*/
-
 				#So no one can do anything nasty, take out the php smarty tags.  Use a user
 				#defined plugin instead.
 				if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
@@ -1026,5 +940,18 @@ function global_content_regex_callback($matches)
 	}
 }
 
+
+function is_sitedown()
+{
+  if( get_site_preference('enablesitedownmessage') !== '1' ) return FALSE;
+  $excludes = get_site_preference('sitedownexcludes','');
+  if( !isset($_SERVER['REMOTE_ADDR']) ) return TRUE;
+  if( empty($excludes) ) return TRUE;
+  
+  $ret = cms_ipmatches($_SERVER['REMOTE_ADDR'],$excludes);
+  if( $ret ) return FALSE;
+  return TRUE;
+}
+
 # vim:ts=4 sw=4 noet
 ?>
