@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 5832 2009-07-23 14:39:54Z calguy1000 $
+#$Id: misc.functions.php 6037 2009-10-03 17:16:59Z calguy1000 $
 
 /**
  * Misc functions
@@ -31,7 +31,7 @@
  */
 function redirect($to, $noappend=false)
 {
-	$_SERVER['PHP_SELF'] = null;
+     $_SERVER['PHP_SELF'] = null;
 
     global $gCms;
 	if (isset($gCms))
@@ -90,6 +90,9 @@ function redirect($to, $noappend=false)
     }
 	*/
 
+    session_write_close();
+
+
     if (headers_sent() && !(isset($config) && $config['debug'] == true))
     {
         // use javascript instead
@@ -2055,5 +2058,15 @@ function is_email( $email, $checkDNS=false ) {
 	return true;
 }
 
+function get_secure_param()
+{
+  $urlext = '?';
+  $str = strtolower(ini_get('session.use_cookies'));
+  if( $str == '0' || $str == 'off' ) {
+    $urlext .= htmlspecialchars(SID).'&';
+  }
+  $urlext .= CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
+  return $urlext;
+}
 # vim:ts=4 sw=4 noet
 ?>
