@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: page.functions.php 5431 2009-02-10 19:03:46Z calguy1000 $
+#$Id: page.functions.php 5753 2009-05-23 16:29:06Z calguy1000 $
 
 /**
  * Page related functions.  Generally these are functions not necessarily
@@ -195,9 +195,59 @@ function generate_user_object($userid)
 		$_SESSION['cms_admin_username'] = $oneuser->username;
 		setcookie('cms_admin_user_id', $oneuser->id);
 		setcookie('cms_passhash', md5(md5($config['root_path'] . '--' . $oneuser->password)));
+		//setcookie(CMS_SECURE_PARAM_NAME, '', time() - 3600);
 	}
 }
 
+function send_recovery_email($username)
+{
+	global $gCms;
+	$config =& $gCms->GetConfig();
+	$userops =& $gCms->GetUserOperations();
+	$user = $userops->LoadUserByUsername($username);
+	
+	//Grab CMSMailer -- *cough* hack
+	$obj = null;
+	if (isset($gCms->modules['CMSMailer']) &&
+		$gCms->modules['CMSMailer']['installed'] == true &&
+		$gCms->modules['CMSMailer']['active'] == true)
+	{
+		$obj = $gCms->modules['CMSMailer']['object'];
+	}
+	
+	if ($obj == null)
+	{
+		return false;
+	}
+	
+	$obj->AddAddress($user->email, $firstname . ' ' . $lastname);
+	$obj->SetSubject(lang('lostpwemailsubject',$gCms->siteprefs['sitename']));
+	
+	$url = $config['root_url'] . '/' . $config['admin_dir'] . '/login.php?recoverme=' . md5(md5($config['root_path'] . '--' . $user->username . md5($user->password)));
+	$body = lang('lostpwemail',$gCms->siteprefs['sitename'], $user->username, $url);
+	
+	$obj->SetBody($body);
+	
+	return $obj->Send();
+}
+
+function find_recovery_user($hash)
+{
+	global $gCms;
+	$config =& $gCms->GetConfig();
+	$userops =& $gCms->GetUserOperations();
+	
+	foreach ($userops->LoadUsers() as $user)
+	{
+		if ($hash == md5(md5($config['root_path'] . '--' . $user->username . md5($user->password))))
+		{
+			return $user;
+		}
+	}
+	
+	return null;
+}
+
 /**
  * Loads all permissions for a particular user into a global variable so we don't hit the db for every one.
  *
@@ -267,6 +317,10 @@ function check_ownership($userid, $contentid = '', $strict = false)
 	$check = false;
 	global $gCms;
 
+	$userops =& $gCms->GetUserOperations();
+	$adminuser = $userops->UserInGroup($userid,1);
+	if( $adminuser ) return true;
+
 	if (!isset($gCms->variables['ownerpages']))
 	{
 		$db =& $gCms->GetDb();
@@ -313,29 +367,14 @@ function check_authorship($userid, $contentid = '')
 	if (!isset($gCms->variables['authorpages']))
 	{
 	  author_pages($userid);
-// 		$db =& $gCms->GetDb();
-
-// 		$variables = &$gCms->variables;
-// 		$variables['authorpages'] = array();
-
-// 		$query = "SELECT content_id FROM ".cms_db_prefix()."additional_users WHERE user_id = ?";
-// 		$result = &$db->Execute($query, array($userid));
-
-// 		while ($result && !$result->EOF)
-// 		{
-// 			$variables['authorpages'][] =& $result->fields['content_id'];
-// 			$result->MoveNext();
-// 		}
-		
-// 		if ($result) $result->Close();
 	}
 
 	if (isset($gCms->variables['authorpages']))
 	{
-		if (in_array($contentid, $gCms->variables['authorpages']))
-		{
-			$check = true;
-		}
+	  if (in_array($contentid, $gCms->variables['authorpages']))
+	    {
+	      $check = true;
+	    }
 	}
 
 	return $check;
