@@ -1,6 +1,6 @@
 <?php
 $lang['info_cmsmailer'] = 'Ce module est utilis&eacute; par de nombreux autres modules pour faciliter l&#039;envoi d&#039;emails. Il doit &ecirc;tre correctement configur&eacute; pour votre h&eacute;bergement. Utiliser les informations fournies par votre h&eacute;bergeur pour r&eacute;gler ces param&egrave;tres. Si vous ne parvenez toujours pas  &agrave; envoyer le message de test correctement, vous devez contacter votre h&eacute;bergeur pour obtenir de l&#039;aide.';
-$lang['charset'] = 'Set d&#039;encodage des caract&egrave;res&nbsp;';
+$lang['charset'] = 'Format d&#039;encodage des caract&egrave;res&nbsp;';
 $lang['sendtestmailconfirm'] = 'Ceci va envoyer un message de test &agrave; l&#039;adresse sp&eacute;cifi&eacute;e. Si le processus d&#039;envoi s&#039;effectue avec succ&egrave;s, vous serez redirig&eacute; &agrave; nouveau vers cette page. Voulez-vous continuer&nbsp;?';
 $lang['settingsconfirm'] = 'Enregistrer les valeurs actuelles dans la configuration de CMSMailer&nbsp;?';
 $lang['testsubject'] = 'Message de test de CMSMailer';
@@ -65,7 +65,7 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <pre>
   $cmsmailer = $this->GetModuleInstance(&#039;CMSMailer&#039;);
   $cmsmailer->AddAddress(&#039;calguy1000@hotmail.com&#039;,&#039;calguy&#039;);
-  $cmsmailer->SetBody(&#039;<h4>This is a test message</h4>&#039;);
+  $cmsmailer->SetBody(&#039;<h4>Ceci est un message de test</h4>&#039;);
   $cmsmailer->IsHTML(true);
   $cmsmailer->SetSubject(&#039;Test message&#039;);
   $cmsmailer->Send();
@@ -315,8 +315,9 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. Tous droits r&eacute;serv&eacute;s.</p>
 <p>Ce module est distribu&eacute; sous la licence <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039; target=&#039;_blank&#039;>GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
 ';
-$lang['utma'] = '156861353.411382167.1233563191.1233741896.1233763634.12';
-$lang['utmz'] = '156861353.1233563191.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,10.0.html|utmcmd=referral';
+$lang['utma'] = '156861353.3936683226868494000.1247055583.1253172677.1253192380.57';
+$lang['utmz'] = '156861353.1253192380.57.28.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/feature_request/list/740|utmcmd=referral';
+$lang['qca'] = '1246563679-91537581-2740096';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
