@@ -31,7 +31,7 @@ $lang['kb'] = 'kB';
 $lang['mb'] = 'MB';
 $lang['files'] = 'Dateien';
 $lang['bytesin'] = 'Bytes in';
-$lang['in'] = 'in';
+$lang['in'] = 'in ';
 $lang['file'] = 'Datei';
 $lang['fileno'] = 'Datei-Nr. ';
 $lang['subdirs'] = 'Unterverzeichnisse';
@@ -127,8 +127,9 @@ $lang['help'] = '		<h3>Was macht das Modul?</h3>
 		<p>Dieses Modul bietet verschiedene Funktionen zur Dateiverwaltung.</p>
 		<h3>Wie wird es eingesetzt?</h3>
 		<p>W&auml;hlen Sie das Modul in der Administration im Men&uuml; &quot;Inhalte&quot; aus.</p>';
-$lang['utma'] = '156861353.717462736.1147511856.1239477650.1240869935.353';
-$lang['utmz'] = '156861353.1234888676.321.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-617342851-1252404665837';
+$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252408135.2';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
