@@ -23,7 +23,7 @@ $lang['delete'] = 'Verwijder';
 $lang['notwritable'] = 'Niet schrijfbaar';
 $lang['filetoobig'] = 'is te groot. Upload is afgebroken.';
 $lang['unknown'] = 'Onbekend';
-$lang['fileoutsideuploads'] = 'Je hebt geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
+$lang['fileoutsideuploads'] = 'U heef geen autorisatie om bestanden buiten de uploads-folder aan te passen! (Daarvoor is Advanced File Management permissie nodig)';
 $lang['writable'] = 'Schrijfbaar';
 $lang['writeprotected'] = 'Schrijf beveiligd';
 $lang['bytes'] = 'bytes ';
@@ -49,13 +49,13 @@ $lang['singledirdeletesuccess'] = 'De map is verwijderd';
 $lang['singledirdeletefail'] = 'Een fout is opgetreden bij het verwijderen van de map (is deze leeg?)';
 $lang['deleteselected'] = 'Verwijder de geselecteerde bestanden';
 $lang['confirmselected'] = 'Weet u het zeker?';
-$lang['confirmdeleteselected'] = 'Weet je zeker dat de geselecteerde bestanden moeten worden verwijderd?';
+$lang['confirmdeleteselected'] = 'Weet u zeker dat de geselecteerde bestanden moeten worden verwijderd?';
 $lang['deleteselectedcancelled'] = 'Verwijderen van geselecteerde bestanden geannuleerd';
 $lang['recursetext'] = 'Recursief in mappen';
 $lang['nofilesselected'] = 'Geen bestanden geselecteerd';
 $lang['moveselected'] = 'Verplaats de geselecteerde bestanden';
 $lang['copyselected'] = 'Kopieer de geselecteerde bestanden';
-$lang['selecttargetdir'] = 'Selecteer de doel-directorie voor het verplaatsen/kopieren';
+$lang['selecttargetdir'] = 'Selecteer de doel-directory voor het verplaatsen/kopieren';
 $lang['movedto'] = 'verplaatst naar';
 $lang['copiedto'] = 'gekopieerd naar';
 $lang['couldnotmove'] = 'kon niet worden verplaatst';
@@ -70,9 +70,9 @@ $lang['group'] = 'Groep';
 $lang['others'] = 'Overigen';
 $lang['newpermissions'] = 'Nieuwe permissies:';
 $lang['setpermissions'] = 'Plaats permissies';
-$lang['permissionstyle'] = 'Permissie style';
-$lang['rwxstyle'] = 'rwx style ';
-$lang['755style'] = '755 style ';
+$lang['permissionstyle'] = 'Permissie stijl';
+$lang['rwxstyle'] = 'rwx stijl ';
+$lang['755style'] = '755 stijl ';
 $lang['quickmode'] = 'Snelle chmod (zoals 777)';
 $lang['chmod'] = 'Wijzig permissies';
 $lang['chmodselected'] = 'Wijzig permissies op geselecteerde bestanden';
@@ -89,7 +89,7 @@ $lang['imsure'] = 'Ik weet het zeker';
 $lang['cancel'] = 'Annuleer';
 $lang['ok'] = 'Ok';
 $lang['uploadnewfile'] = 'Upload nieuwe bestanden:';
-$lang['unpackafterupload'] = 'Probeer het bestand uit te pakken na upload (alleen tgz en meeste zip-bestanden)?';
+$lang['unpackafterupload'] = 'Probeer het bestand na upload, uit te pakken (alleen tgz en meeste zip-bestanden)?';
 $lang['uploadsuccess'] = 'is ge&uuml;pload';
 $lang['uploadfail'] = 'upload niet geslaagd';
 $lang['unpacksuccess'] = 'is uitgepakt';
@@ -122,13 +122,14 @@ $lang['advancedhelp'] = 'Geeft u toegang tot het gehele CMSMS bestandssysteem, n
 $lang['showhiddenfileshelp'] = 'Alleen effectief in de gevorderenmodus';
 $lang['showhiddenfiles'] = 'Toon verborgen bestanden';
 $lang['settingsconfirmsingledelete'] = 'Bevestig verwijdering van een enkel bestand?';
-$lang['settingssaved'] = 'Instellingen bewaard';
+$lang['settingssaved'] = 'Instellingen opgeslagen';
 $lang['help'] = '		<h3>Wat doet het?</h3>
 		<p>Deze module verzorgt een bestandsbeheer functionaliteit</p>
 		<h3>Hoe gebruikt u het</h3>
 		<p>Selecteer Bestandsbeheer in het Inhoudsmenu.</p>';
-$lang['utma'] = '156861353.1764090269059867100.1239886062.1247056319.1247079810.23';
-$lang['utmz'] = '156861353.1247056319.22.2.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,35313.0.html|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1102358534.1252830695.1253555343.1253609589.34';
+$lang['utmz'] = '156861353.1253452193.26.10.utmccn=(referral)|utmcsr=zeijennu.tjassens.eu|utmcct=/admin/editevent.php|utmcmd=referral';
+$lang['qca'] = 'P0-1787501767-1252830695602';
+$lang['utmb'] = '156861353.5.10.1253609589';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
