@@ -7,20 +7,19 @@ $hm =& $gCms->GetHierarchyManager();
 
 $usefile = true;
 $tpl_name = $this->GetPreference('default_template','simple_navigation.tpl');
-if( !endswith($tpl_name,'.tpl') )
+if (isset($params['template']) && $params['template'] != '')
+{
+  $tpl_name = $params['template'];
+}
+if( endswith($tpl_name, '.tpl') )
+  {
+    $usefile = true;
+  }
+else
   {
     $usefile = false;
   }
 
-if (isset($params['template']) && $params['template'] != '')
-{
-	$tpl_name = $params['template'];
-	if (!endswith($tpl_name, '.tpl'))
-	{
-		$usefile = false;
-	}
-}
-
 $mdid = md5($gCms->variables['content_id'].implode('|', $params));
 
 $cached = false;
@@ -87,12 +86,14 @@ if (!$cached)
 		if (isset($curnode))
 		{
 			$curcontent =& $curnode->GetContent();
-			$properparentpos = $this->nthPos($curcontent->Hierarchy() . '.', '.', intval($params['start_level']) - 1);
-			if ($properparentpos > -1)
-			{
-				$prevdepth = intval($params['start_level']);
-				$rootnode =& $hm->getNodeByHierarchy(substr($curcontent->Hierarchy(), 0, $properparentpos));
-			}
+			if( $curcontent )  {
+			  $properparentpos = $this->nthPos($curcontent->Hierarchy() . '.', '.', intval($params['start_level']) - 1);
+			  if ($properparentpos > -1)
+			  {
+			    $prevdepth = intval($params['start_level']);
+			    $rootnode =& $hm->getNodeByHierarchy(substr($curcontent->Hierarchy(), 0, $properparentpos));
+			  }
+                        }
 		}
 	}
 	else if (isset($params['items']))
@@ -168,7 +169,7 @@ if (!$cached)
 		$smarty->assign('count', count($nodelist));
 		$smarty->assign_by_ref('nodelist', $nodelist);
 		if ($usefile)
-			echo $this->ProcessTemplate($tpl_name, $mdid, false, $gCms->variables['content_id']);
+		  echo $this->ProcessTemplate($tpl_name, $mdid, false, $gCms->variables['content_id']);
 		else
 		  echo $this->ProcessTemplateFromDatabase($tpl_name, $mdid, false);
 	}
