@@ -66,6 +66,7 @@ $lang['help'] = '	<h3>Hva gj&oslash;r denne?</h3>
 			<li>$node->prevdepth -- Dybde (niv&aring;) p&aring; klyngen som var rett f&oslash;r denne</li>
 			<li>$node->haschildren -- Returnerer sann om denne klyngen har barneklynger &aring; vise</li>
 			<li>$node->menutext -- Meny Tekst</li>
+			<li>$node->raw_menutext -- Menytekst uten konverterte html-entiteter</li>
 			<li>$node->alias -- Side alias</li>
 			<li>$node->extra1 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra1 page property.</li>
 			<li>$node->extra2 -- Denne er kun tilgjengelig om parameteren loadprops er satt i menytaggen. Dette feltet inneholder verdien til extra2 sideegenskapen.</li>
@@ -88,8 +89,9 @@ $lang['notemplatefiles'] = 'Ingen fil maler i %s';
 $lang['notemplatename'] = 'Ingen malnavn oppgitt.';
 $lang['templatecontent'] = 'Mal innhold';
 $lang['templatenameexists'] = 'En mal med dette navnet eksisterer allerede';
-$lang['utmz'] = '156861353.1245190196.1444.36.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/download_themes.html';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1246034439.1246038755.1490';
+$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1252014923.1252077609.1842';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1246038755';
+$lang['utmb'] = '156861353.1.10.1252077609';
 ?>
\ No newline at end of file
