@@ -10,9 +10,9 @@ $lang['anonymous'] = 'Anonym';
 $lang['unknown'] = 'Unbekannt';
 $lang['fesubmit_redirect'] = 'Die Seiten-ID oder der Seiten-Alias der Seite, auf die der Einsender eines Artikels &uuml;ber die fesubmit-Aktion weitergeleitet werden soll';
 $lang['allow_summary_wysiwyg'] = 'Den WYSIWYG-Editor f&uuml;r das Zusammenfassungsfeld verwenden';
-$lang['title_browsecat_template'] = 'Template-Editor f&uuml;r die Kategorien-Anzeige';
+$lang['title_browsecat_template'] = 'Vorlageneditor f&uuml;r die Kategorien-Anzeige';
 $lang['title_browsecat_sysdefault'] = 'Voreingestelltes Template f&uuml;r die Kategorien-Anzeige';
-$lang['browsecattemplate'] = 'Templates f&uuml;r die Kategorien-Anzeige';
+$lang['browsecattemplate'] = 'Vorlagen f&uuml;r die Kategorien-Anzeige';
 $lang['error_filesize'] = 'Die hochgeladene Datei &uuml;berschreitet die maximal erlaubte Gr&ouml;&szlig;e';
 $lang['post_date_desc'] = 'nach Erstellungsdatum absteigend';
 $lang['post_date_asc'] = 'nach Erstellungsdatum aufsteigend';
@@ -28,7 +28,7 @@ $lang['error_mkdir'] = 'Konnte das Verzeichnis %s nicht erstellen';
 $lang['expiry_interval'] = 'Voreingestellte Anzahl der Tage, nach denen ein Artikel nicht mehr auf der Webseite angezeigt werden soll (falls die Zeitsteuerung verwendet wird)';
 $lang['removed'] = 'Entfernt';
 $lang['msg_contenttype_removed'] = 'Der Inhaltstyp &bdquo;News&ldquo; wird nicht mehr unterst&uuml;tzt. Bitte verwenden Sie in Ihren Seiten-Templates bzw. -inhalten anstatt dessen den {news}-Tag mit den entsprechenden Parametern.';
-$lang['delete_selected'] = 'ausgew&auml;hlte Artikel l&ouml;schen';
+$lang['delete_selected'] = 'Ausgew&auml;hlte Artikel l&ouml;schen';
 $lang['areyousure_deletemultiple'] = 'Wollen Sie wirklich alle ausgew&auml;hlten Artikel l&ouml;schen?\nDies kann NICHT r&uuml;ckg&auml;ngig gemacht werden!';
 $lang['error_templatenamexists'] = 'Es existiert bereits ein Template mit diesem Namen!';
 $lang['error_noarticlesselected'] = 'Es wurden keine Artikel ausgew&auml;hlt';
@@ -37,33 +37,33 @@ $lang['select'] = 'Ausw&auml;hlen';
 $lang['approve'] = 'Status auf &bdquo;ver&ouml;ffentlicht&ldquo; setzen';
 $lang['revert'] = 'Status auf &bdquo;Entwurf&ldquo; setzen';
 $lang['hide_summary_field'] = 'Das Zusammenfassungsfeld verbergen, wenn ein Artikel hinzugef&uuml;gt oder bearbeitet wird';
-$lang['textbox'] = 'einzeiliges Textfeld';
+$lang['textbox'] = 'Einzeiliges Textfeld';
 $lang['checkbox'] = 'Kontrollk&auml;stchen';
-$lang['textarea'] = 'mehrzeiliger Textbereich';
+$lang['textarea'] = 'Mehrzeiliger Textbereich';
 $lang['file'] = 'Datei';
 $lang['auto_create_thumbnails'] = 'F&uuml;r Dateien mit dieser Namenserweiterung automatisch ein Vorschaubild erstellen';
 $lang['allowed_upload_types'] = 'Nur Dateien mit dieser Namenserweiterung d&uuml;rfen hochgeladen werden';
-$lang['fielddefupdated'] = 'Feld-Definition aktualisiert';
-$lang['editfielddef'] = 'Feld-Definition bearbeiten';
-$lang['up'] = 'nach oben';
-$lang['down'] = 'nach unten';
-$lang['fielddefdeleted'] = 'Feld-Definition gel&ouml;scht';
-$lang['nameexists'] = 'Ein Feld mit diesem Namen existiert bereits';
+$lang['fielddefupdated'] = 'Das Extra-Feld wurde aktualisiert';
+$lang['editfielddef'] = 'Extra-Feld bearbeiten';
+$lang['up'] = 'Nach oben';
+$lang['down'] = 'Nach unten';
+$lang['fielddefdeleted'] = 'Extra-Feld gel&ouml;scht';
+$lang['nameexists'] = 'Ein Extra-Feld mit diesem Namen existiert bereits';
 $lang['notanumber'] = 'Die maximale L&auml;nge ist keine Zahl';
-$lang['fielddef'] = 'Feld-Definition';
-$lang['fielddefadded'] = 'Die Feld-Definition wurde erfolgreich hinzugef&uuml;gt';
-$lang['public'] = '&ouml;ffentlich';
+$lang['fielddef'] = 'Extra-Feld';
+$lang['fielddefadded'] = 'Das Extra-Feld wurde erfolgreich hinzugef&uuml;gt';
+$lang['public'] = '&Ouml;ffentlich';
 $lang['type'] = 'Typ';
 $lang['info_maxlength'] = 'Die maximale L&auml;nge hat nur Auswirkungen auf einzeilige Textfelder.';
 $lang['maxlength'] = 'Maximale L&auml;nge';
-$lang['addfielddef'] = 'Feld-Definition hinzuf&uuml;gen';
-$lang['customfields'] = 'Feld-Definitionen';
-$lang['deprecated'] = 'nicht unterst&uuml;tzt';
+$lang['addfielddef'] = 'Extra-Feld hinzuf&uuml;gen';
+$lang['customfields'] = 'Extra-Felder';
+$lang['deprecated'] = 'Nicht unterst&uuml;tzt';
 $lang['subject_newnews'] = 'Ein neuer Artikel wurde ins System eingestellt';
 $lang['email_subject'] = 'Betreff der ausgehenden Email';
 $lang['email_template'] = 'Inhalt der Email-Nachricht';
 $lang['formsubmit_emailaddress'] = 'Email-Adresse zur Benachrichtigung bei neuen Artikeln';
-$lang['extra'] = 'Extrafeld';
+$lang['extra'] = 'Extra-Feld';
 $lang['uploadscategory'] = 'Kategorie im Uploads-Modul';
 $lang['title_available_templates'] = 'Verf&uuml;gbare Templates';
 $lang['resettodefault'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
@@ -78,14 +78,14 @@ $lang['title_detail_sysdefault'] = 'Standard-Template f&uuml;r die Details';
 $lang['info_sysdefault2'] = '<strong>Hinweis:</strong> In den Textbereichen dieser Registerkarte k&ouml;nnen Sie die Templates vordefinieren, die automatisch eingef&uuml;gt werden, wenn Sie eine neues Zusammenfassungs-, Detail- oder Formular-Template erstellen. Das &Auml;ndern/Speichern der Inhalte in diesem Reiter hat <strong>keine Auswirkungen auf die aktuelle Anzeige</strong>.';
 $lang['info_sysdefault'] = '<em>(der Inhalt, der standardm&auml;&szlig;ig beim Erstellen eines neuen Templates verwendet wird)</em>';
 $lang['template'] = 'Template ';
-$lang['prompt_name'] = 'Name';
+$lang['prompt_name'] = 'Name ';
 $lang['prompt_default'] = 'Standard';
 $lang['prompt_newtemplate'] = 'Ein neues Template erstellen';
 $lang['help_pagelimit'] = 'Maximale Anzahl der anzuzeigenden Eintr&auml;ge (pro Seite). Ohne diesen Parameter werden alle Eintr&auml;ge angezeigt. Wenn dieser Parameter gesetzt wurde und mehr Eintr&auml;ge vorhanden sind, als pro Seite angezeigt werden sollen, werden Links eingeblendet, um vorw&auml;rts oder r&uuml;ckw&auml;rts zu den n&auml;chsten Seiten bl&auml;ttern zu k&ouml;nnen.';
 $lang['prompt_page'] = 'Seite';
 $lang['firstpage'] = '&laquo;';
-$lang['prevpage'] = '<';
-$lang['nextpage'] = '>';
+$lang['prevpage'] = '&lsaquo;';
+$lang['nextpage'] = '&rsaquo;';
 $lang['lastpage'] = '&raquo;';
 $lang['prompt_of'] = 'von';
 $lang['prompt_pagelimit'] = 'Artikel pro Seite';
@@ -127,15 +127,15 @@ $lang['edit'] = 'Bearbeiten';
 $lang['enddate'] = 'Endzeitpunkt';
 $lang['endrequiresstart'] = 'Wenn Sie einen Endzeitpunkt angeben, m&uuml;ssen Sie auch ein Startzeitpunkt festgelegen.';
 $lang['entries'] = '%s Eintr&auml;ge';
-$lang['status'] = 'Status';
+$lang['status'] = 'Status ';
 $lang['expiry'] = 'Ablauf';
 $lang['filter'] = 'Artikel-Filter';
 $lang['more'] = 'Weiterlesen &hellip;';
 $lang['category_label'] = 'Kategorie:';
 $lang['author_label'] = 'Erstellt von:';
 $lang['moretext'] = 'Text f&uuml;r den Link &bdquo;Weiterlesen &hellip;&ldquo;';
-$lang['name'] = 'Name';
-$lang['news'] = 'News';
+$lang['name'] = 'Name ';
+$lang['news'] = 'News ';
 $lang['news_return'] = 'Zur&uuml;ck';
 $lang['newcategory'] = 'Neue Kategorie';
 $lang['needpermission'] = 'Sie ben&ouml;tigen die Berechtigung &bdquo;%s&ldquo;, um diese Funktion nutzen zu k&ouml;nnen.';
@@ -274,9 +274,11 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 <ul>
 	<li><strong>itemcount</strong> - maximale Anzahl der anzuzeigenden News-Artikel
 	<li><strong>entry->authorname</strong> - vollst&auml;ndiger Name des News-Autors (Vor-/Nachname), wie er in der Benutzer-Verwaltung gespeichert ist</li>
-</ul>';
-$lang['utma'] = '156861353.1550749088.1249297822.1249297822.1249297822.1';
-$lang['utmb'] = '156861353';
+</ul>
+<p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &quot;musterfeld&quot; &uuml;ber die Variable entry->musterfeld abfragen.</p>
+<p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&quot;_&quot;) ersetzt werden.</p> ';
+$lang['qca'] = 'P0-617342851-1252404665837';
+$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252405474.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1249297822.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 ?>
\ No newline at end of file
