@@ -3,7 +3,7 @@ $lang['expired_searchable'] = 'Utl&oslash;pte artikler f&aring;r vises i s&oslas
 $lang['helpshowall'] = 'Vis alle artikler, uten &aring; ta hensyn til utl&oslash;psdato';
 $lang['error_invaliddates'] = 'En eller flere av datoene som er oppgitt er ugyldige';
 $lang['notify_n_draft_items_sub'] = '%d nyhetsartikler';
-$lang['notify_n_draft_items'] = 'Du har <a href="moduleinterface.php?module=News">%d Nyhetsartikler</a>som ikke er publiserte';
+$lang['notify_n_draft_items'] = 'Du har %s som ikke er publiserte';
 $lang['unlimited'] = 'Ubegrenset';
 $lang['none'] = 'Ingen';
 $lang['anonymous'] = 'Anonym';
@@ -169,65 +169,65 @@ $lang['eventdesc-NewsArticleAdded'] = 'Sendt n&aring;r en artikkel er lagt til.'
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sendt n&aring;r en artikkel er lagt til.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id for nyhets artikkelen</li>
-<li>\&quot;category_id\&quot; - Id for kategorien for denne artiklen</li>
-<li>\&quot;title\&quot; - Artikkel tittel</li>
-<li>\&quot;content\&quot; - Artikkelens innhold</li>
-<li>\&quot;summary\&quot; - Artikkel sammendrag</li>
-<li>\&quot;status\&quot; - Status for artikkelen (&quot;draft&quot; eller &quot;publish&quot;)</li>
-<li>\&quot;start_time\&quot; - Dato for n&aring;r artikkelen skal begynne &aring; vises</li>
-<li>\&quot;end_time\&quot; - Dato for n&aring;r artikkelen ikke skal vises lengre</li>
-<li>\&quot;useexp\&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
+<li>&quot;news_id&quot; - Id for nyhets artikkelen</li>
+<li>&quot;category_id&quot; - Id for kategorien for denne artiklen</li>
+<li>&quot;title&quot; - Artikkel tittel</li>
+<li>&quot;content&quot; - Artikkelens innhold</li>
+<li>&quot;summary&quot; - Artikkel sammendrag</li>
+<li>&quot;status&quot; - Status for artikkelen (&quot;draft&quot; eller &quot;publish&quot;)</li>
+<li>&quot;start_time&quot; - Dato for n&aring;r artikkelen skal begynne &aring; vises</li>
+<li>&quot;end_time&quot; - Dato for n&aring;r artikkelen ikke skal vises lengre</li>
+<li>&quot;useexp&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
 </ul>';
 $lang['eventdesc-NewsArticleEdited'] = 'Sendt n&aring;r en artikkel er redigert.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Sendt n&aring;r en artikkel er redigert.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id for nyhetsartikkelen</li>
-<li>\&quot;category_id\&quot; - Id for kategorien for denne artikkelen</li>
-<li>\&quot;title\&quot; - Artikkeltittel</li>
-<li>\&quot;content\&quot; - Artikkel innhold</li>
-<li>\&quot;summary\&quot; - Artikkel sammedrag</li>
-<li>\&quot;status\&quot; - Artikkel status (\&quot;draft\&quot; eller \&quot;publish\&quot;)</li>
-<li>\&quot;start_time\&quot; - Dato artikkelen skal begynne &aring; vises</li>
-<li>\&quot;end_time\&quot; - Dato artikkelen ikke skal vises lengre</li>
-<li>\&quot;useexp\&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
+<li>&quot;news_id&quot; - Id for nyhetsartikkelen</li>
+<li>&quot;category_id&quot; - Id for kategorien for denne artikkelen</li>
+<li>&quot;title&quot; - Artikkeltittel</li>
+<li>&quot;content&quot; - Artikkel innhold</li>
+<li>&quot;summary&quot; - Artikkel sammedrag</li>
+<li>&quot;status&quot; - Artikkel status (&quot;draft&quot; eller &quot;publish&quot;)</li>
+<li>&quot;start_time&quot; - Dato artikkelen skal begynne &aring; vises</li>
+<li>&quot;end_time&quot; - Dato artikkelen ikke skal vises lengre</li>
+<li>&quot;useexp&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
 </ul>
 ';
 $lang['eventdesc-NewsArticleDeleted'] = 'Sendt n&aring;r en artikkel er slettet.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Sendt n&aring;r en artikkel er slettet.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id for nyhetsartikkelen</li>
+<li>&quot;news_id&quot; - Id for nyhetsartikkelen</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryAdded'] = 'Sendt n&aring;r en kategori er lagt til.';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>Sendt n&aring;r en kategori er lagt til.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id for nyhetskategorien</li>
-<li>\&quot;name\&quot; - Navn p&aring; nyhetskategorien</li>
+<li>&quot;category_id&quot; - Id for nyhetskategorien</li>
+<li>&quot;name&quot; - Navn p&aring; nyhetskategorien</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryEdited'] = 'Sendt n&aring;r en kategori er redigert.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Sendt n&aring;r en kategori er redigert.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id for nyhetskategorien</li>
-<li>\&quot;name\&quot; - Navn p&aring; nyhetskategorien</li>
-<li>\&quot;origname\&quot; - Det orginale navnet p&aring; nyhetskategorien</li>
+<li>&quot;category_id&quot; - Id for nyhetskategorien</li>
+<li>&quot;name&quot; - Navn p&aring; nyhetskategorien</li>
+<li>&quot;origname&quot; - Det orginale navnet p&aring; nyhetskategorien</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryDeleted'] = 'Sendt n&aring;r en kategori er slettet.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sendt n&aring;r en kategori er slettet.</p>
 <h4>Parametere</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id for nyhets kategorien</li>
-<li>\&quot;name\&quot; - Navnet p&aring; den slettede kategorien</li>
+<li>&quot;category_id&quot; - Id for den slettede nyhetskategorien</li>
+<li>&quot;name&quot; - Navnet p&aring; den slettede kategorien</li>
 </ul>
 ';
 $lang['help_articleid'] = 'Denne parameter er kun gyldig i detaljvisning. Den tillater &aring; spesifisere hvilken nyhetsartikkel som skal vises i detaljmodus. Om den spesielle verdien -1 er benyttet vil systemet vise den nyeste, publiserte, ikke utl&oslash;pte artikkelen.';
-$lang['helpnumber'] = 'Maksimalt antall elementer som skal vises (ingen verdi vil medf&oslash;re at alle elementer vises).';
+$lang['helpnumber'] = 'Maksimalt antall elementer som skal vises (per side) (ingen verdi vil medf&oslash;re at alle elementer vises). Denne er synonym for pagelimit parameteren.';
 $lang['helpstart'] = 'Start med artikkel n-- dersom ingen parameter er gitt vil visningen starte fra f&oslash;rste artikkel.';
 $lang['helpcategory'] = 'Benyttet i sammendragsvisning for kun &aring; vise elementer fra den spesifiserte kategorien. <b>Bruk * etter navnet for &aring; vise underelementer.</b>  Flere kategorier kan bli brukt dersom disse er separert med komma. Om ingen verdi oppgis vil det resultere i at alle kategorier vises. Denne parameter virker ogs&aring; p&aring; frontend submit handlingen, men st&oslash;tter kun et kategori navn.';
 $lang['helpmoretext'] = 'Tekst som skal vises p&aring; slutten av nyhetssaken dersom innlegget er lengre enn sammendragslengden. Standard verdi er &quot;more...&quot;';
@@ -242,13 +242,13 @@ $lang['helpshowarchive'] = 'Vis bare utdaterte nyhetsartikler.';
 $lang['helpbrowsecat'] = 'Viser en s&oslash;kbar kategoriliste';
 $lang['helpaction'] = 'Overstyrer standard handlingen. Mulige verdier er:
 <ul>
-<li>&amp;quot;detail&amp;quot; - for &aring; vise en spesifisert articleid i detaljvisningsmodus.</li>
-<li>&amp;quot;default&amp;quot; - for &aring; vise sammendragsvisningen</li>
-<li>&amp;quot;fesubmit&amp;quot; - for &aring; vise et forside skjema for &aring; tillate brukere &aring; bidra med nyhetsartikler fra nettsiden.</li>
-<li>&amp;quot;browsecat&amp;quot; - for &aring; vise en s&oslash;kbar kategoriliste.</li>
+<li>&quot;detail&quot; - for &aring; vise en spesifisert articleid i detaljvisningsmodus.</li>
+<li>&quot;default&quot; - for &aring; vise sammendragsvisningen</li>
+<li>&quot;fesubmit&quot; - for &aring; vise et forside skjema for &aring; tillate brukere &aring; bidra med nyhetsartikler fra nettsiden.</li>
+<li>&quot;browsecat&quot; - for &aring; vise en s&oslash;kbar kategoriliste.</li>
 </ul>';
 $lang['help'] = '<h3>Viktige merknader</h3>
-<p>Versjon 2.9 av News og h&oslash;yere har fjernet formatpostdate medlemmet fra malene og har ogs&aring; fjernet dataformat parameteren.  Du b&oslash;r benytte cms_data_format (slik det er vist i standard malene) for &aring; formatere datoer. Og du b&oslash;r benytte entry->postdate i stedet for entry->formatpostdate i dine maler.</p>
+<p>Versjon 2.9 av News og h&oslash;yere har fjernet formatpostdate medlemmet fra malene og har ogs&aring; fjernet dateformat parameteren. Du b&oslash;r benytte  cms_date_format  (slik det er vist i standard malene) for &aring; formatere datoer. Og du b&oslash;r benytte entry->postdate i stedet for entry->formatpostdate i dine maler. <br />Tips: For &aring; f&aring; norsk &aelig; og &oslash; p&aring; ukedag s&aring; kan det hende du ogs&aring; m&aring; tilf&oslash;ye  |htmlentities  bak  cms_date_format  som dette: {$entry->postdate|cms_date_format:&quot;%A %e. %B %Y&quot;|htmlentities}</p>
 
 <h3>Hva gj&oslash;r denne modulen?</h3>
 <p>News er en modul for visning av nyhetsartikler p&aring; din side. Den ligner en blogg, men har flere muligheter!.  
@@ -260,7 +260,7 @@ Herfra kan du legge til, redigere eller slette nyheter for kategorien.</p>
         <h4>Egendefinerte felter</h4>
 	<p>Nyhetsmodulen tillater definering av mange egendefinerte felter (inkludert filer og bilder) som vil tillate deg &aring; koble pdf filer eller flere bilders til dine artikler.</p>
         <h4>Kategorier</h4>
-	<p>_Nyheter st&oslash;tter en hierarktisk kategori mekanisme for &aring; organisere dine artikler. En hyhetsartikkel kan kun tilh&oslash;re en posisjon i hierarkiet.</p>
+	<p>Nyheter st&oslash;tter en hierarktisk kategori mekanisme for &aring; organisere dine artikler. En hyhetsartikkel kan kun tilh&oslash;re en posisjon i hierarkiet.</p>
 	<h4>Utl&oslash;psdato og Status</h4>
 	<p>Hver nyhetsartikkel kan ha en utl&oslash;psdato(valgfritt) og n&aring;r denne utl&oslash;per vil artikkelen ikke vises p&aring; din nettside. I tillegg kan artikler ogs&aring; merkes som <em>kladd</em> for &aring; sette dem til &aring; ikke vises p&aring; din nettside.</p>
 	<h3>Sikkerhet</h3>
@@ -277,14 +277,14 @@ Dette vil sette inn modulen i din mal eller side hvor du m&aring;tte &oslash;nsk
 <h3>Maler</h3>
 <p>Fra og med versjon 2.3 st&oslash;tter News flere database maler, og st&oslash;tter ikke lenger filmaler. Brukere som brukte det gamle filmal systemet kan f&oslash;lge disse trinnene (for hver filmal):
 <ul>
-<li>Kopier filemalen til utklippstavla</li>
+<li>Kopier filmalen til utklippstavla</li>
 <li>Opprett en ny databasemal <em>(enten sammendrag eller detalj som trengs)</em>.  Gi den nye malen samme navn (inkludert .tpl endelse) som den gamle filmalen, og lim inn innholdet.</li>
 <li>Trykk Oppdater</li>
 </ul>
 
 <p>Dersom du f&oslash;lger disse trinnene skulle det l&oslash;se problemet med at dine nyhetsamaler ikke blir funnet og lignende smarty feil, n&aring;r du oppgraderer til en versjon av CMS som har News 2.3 eller h&oslash;yere.</p>';
-$lang['utmz'] = '156861353.1234296378.907.26.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,7.0.html';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1234708756.1234716045.929';
+$lang['utmz'] = '156861353.1243118268.1334.33.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1244280118.1244298455.1393';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1234716045';
+$lang['utmb'] = '156861353.2.10.1244298455';
 ?>
\ No newline at end of file
