@@ -13,7 +13,7 @@ $lang['allow_summary_wysiwyg'] = 'Gebruik een WYSIWYG voor het samenvattings-vel
 $lang['title_browsecat_template'] = 'Browsen categoriesjabloon-editor';
 $lang['title_browsecat_sysdefault'] = 'Standaard browse-categoriesjabloon';
 $lang['browsecattemplate'] = 'Browsen categoriesjablonen';
-$lang['error_filesize'] = 'Een geupload bestand overschrijdt de maximum toegestane grootte.';
+$lang['error_filesize'] = 'Een ge&uuml;pload bestand overschrijdt de maximum toegestane grootte.';
 $lang['post_date_desc'] = 'Bijdragedatum aflopend';
 $lang['post_date_asc'] = 'Bijdragedatum oplopend';
 $lang['expiry_date_desc'] = 'Verloopdatum aflopend';
@@ -151,7 +151,7 @@ $lang['numbertodisplay'] = 'Aantal weer te geven (leeg is alles weergeven)';
 $lang['print'] = 'Afdrukken';
 $lang['postdate'] = 'Plaatsingsdatum';
 $lang['postinstall'] = 'Zorg ervoor dat gebruikers die nieuwsberichten beheren &quot;Modify News&quot; rechten krijgen.';
-$lang['selectcategory'] = 'Selecteer categorie';
+$lang['selectcategory'] = 'Selecteer een categorie';
 $lang['showchildcategories'] = 'Toon onderliggende categorie&euml;n';
 $lang['sortascending'] = 'Sorteer oplopend';
 $lang['startdate'] = 'Begindatum';
@@ -165,7 +165,7 @@ $lang['title'] = 'Titel';
 $lang['options'] = 'Opties';
 $lang['optionsupdated'] = 'De opties zijn bijgewerkt.';
 $lang['useexpiration'] = 'Gebruik vervaldatum';
-$lang['eventdesc-NewsArticleAdded'] = 'Verzonden als een bericht is toegevoegd.';
+$lang['eventdesc-NewsArticleAdded'] = 'Een tag die wordt aangeroepen als een bericht is toegevoegd.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Verzonden als een bericht is toegevoegd.</p>
 <h4>Parameters</h4>
 <ul>
@@ -180,7 +180,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>Verzonden als een bericht is toegevoeg
 <li>\&quot;useexp\&quot; - Of de verloopdatum genegeerd moet worden of niet</li>
 </ul>
 ';
-$lang['eventdesc-NewsArticleEdited'] = 'Verzonden als een bericht is bewerkt.';
+$lang['eventdesc-NewsArticleEdited'] = 'Een tag die wordt aangeroepen als een bericht is bewerkt.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Verzonden als een bericht is bewerkt.</p>
 <h4>Parameters</h4>
 <ul>
@@ -195,14 +195,14 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>Verzonden als een bericht is bewerkt.
 <li>\&quot;useexp\&quot; - Of de verloopdatum genegeerd moet worden of niet</li>
 </ul>
 ';
-$lang['eventdesc-NewsArticleDeleted'] = 'Verzonden als een bericht is verwijderd.';
+$lang['eventdesc-NewsArticleDeleted'] = 'Een tag die wordt aangeroepen als een bericht is verwijderd.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Verzonden als een bericht is verwijderd.</p>
 <h4>Parameters</h4>
 <ul>
 <li>\&quot;news_id\&quot; - Id van het bericht</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryAdded'] = 'Verzonden als een categorie is toegevoegd.';
+$lang['eventdesc-NewsCategoryAdded'] = 'Een tag die wordt aangeroepen als een categorie is toegevoegd.';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>Verzonden als een categorie is toegevoegd.</p>
 <h4>Parameters</h4>
 <ul>
@@ -210,7 +210,7 @@ $lang['eventhelp-NewsCategoryAdded'] = '<p>Verzonden als een categorie is toegev
 <li>\&quot;name\&quot; - Naam van de nieuwscategorie</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryEdited'] = 'Verzonden als een categorie is bewerkt.';
+$lang['eventdesc-NewsCategoryEdited'] = 'Een tag die wordt aangeroepen als een categorie is bewerkt.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Verzonden als een categorie is bewerkt.</p>
 <h4>Parameters</h4>
 <ul>
@@ -219,7 +219,7 @@ $lang['eventhelp-NewsCategoryEdited'] = '<p>Verzonden als een categorie is bewer
 <li>\&quot;origname\&quot; - De originele naam van de nieuwscategorie</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryDeleted'] = 'Verzonden als een categorie is verwijderd.';
+$lang['eventdesc-NewsCategoryDeleted'] = 'Een tag die wordt aangeroepen als een categorie is verwijderd.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Verzonden als een categorie is verwijderd.</p>
 <h4>Parameters</h4>
 <ul>
@@ -243,10 +243,10 @@ $lang['helpshowarchive'] = 'Toon alleen verlopen artikelen.';
 $lang['helpbrowsecat'] = 'Toon een doorbladerbare categorielijst.';
 $lang['helpaction'] = 'Negeer de standaardtaak. Mogelijke waarden zijn:
 <ul>
-<li>&amp;quot;detail&amp;quot; - toon van een specifiek artikel ID de detail weergave.</li>
-<li>&amp;quot;default&amp;quot; - toon de samenvattingsweergave</li>
-<li>&amp;quot;fesubmit&amp;quot; - toon het frontend formulier om (ingelogde) gebruikers de mogelijkheid te geven om nieuwsberichten aan te leveren.</li>
-<li>&amp;quot;browsecat&amp;quot; - toon een overzichtslijst van categori&euml;n.</li>
+<li>&quot;detail&quot; - toon van een specifiek artikel ID de detail weergave.</li>
+<li>&quot;default&quot; - toon de samenvattingsweergave</li>
+<li>&quot;fesubmit&quot; - toon het frontend formulier om (ingelogde) gebruikers de mogelijkheid te geven om nieuwsberichten aan te leveren.</li>
+<li>&quot;browsecat&quot; - toon een overzichtslijst van categori&euml;n.</li>
 </ul>';
 $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 
@@ -267,7 +267,7 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 	<p>De gebruiker moet lid zijn van een groep met groepsrecht &#039;Modify News&#039; om berichten te mogen aanmaken, bewerken of verwijderen.</p>
 	<p>Om een opmaaksjabloon te mogen bewerken moet de gebruiker lid zijn van een groep met &#039;Modify Templates&#039; rechten.</p>
 	<p>Algemene News-voorkeuren kunnen alleen door gebruikers veranderd worden die onderdeel zijn van een groep met &#039;Modify Site Preferences&#039; rechten.</p>
-	<h3>Hoe gebruik is het?</h3>
+	<h3>Hoe gebruik ik het?</h3>
 	<p>De eenvoudigste manier om deze module te gebruiken is de {news} tag in uw sjabloon of pagina op te nemen op die plek waar de nieuwsberichten getoond moeten worden. De code zal er dan ongeveer als volgt uitzien: <code>{news number=&#039;5&#039;}</code></p>
 <h3>Sjablonen</h3>
 	<p>Vanaf versie 2.3 ondersteunt News meerdere database-sjablonen en is de ondersteuning van extra bestandssjablonen gestaakt. Gebruikers die de oude bestandssjablonen gebruikten, moeten voor ieder sjabloon de volgende stappen doorlopen:
@@ -277,8 +277,9 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['utma'] = '156861353.799969050.1225024056.1244555916.1244572805.339';
-$lang['utmz'] = '156861353.1244550087.337.59.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,34493.new.html';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1764090269059867100.1239886062.1251546993.1251625156.65';
+$lang['utmz'] = '156861353.1251392261.61.11.utmccn=(referral)|utmcsr=classic-motorcycle-demo-team.nl|utmcct=/admin/addcontent.php|utmcmd=referral';
+$lang['qca'] = '4824ac14-af799-a4257-f4cde';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
