@@ -36,7 +36,7 @@ class Printing extends CMSModule {
 	}
 
 	function GetVersion() {
-		return '1.0.2';
+		return '1.0.4';
 	}
 
 	function MinimumCMSVersion() {
@@ -82,33 +82,12 @@ class Printing extends CMSModule {
   }
 
   function GetCurrentURL($showtemplate=false) {
-    //$url = "http://".$_SERVER['HTTP_HOST'].$_SERVER['SCRIPT_NAME'];
-    /*if (!empty($_SERVER["QUERY_STRING"])) {
-      $url .= "?".$_SERVER['QUERY_STRING']."&showtemplate=false";
-    } else {
-      $url .= "?showtemplate=false";
-    }*/
-    //$url = str_replace("index.php?page=", "", $urlBASE);
     $url = "http://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
     if ($showtemplate) return $url;
     if (strpos($url,'?')) { //other params present
-      $url.="&showtemplate=false";
+      $url .= "&showtemplate=false";
     } else {
-      global $config;
-      if ($config["url_rewriting"]=='internal') {
-        $pos=strpos($url,"index.php/");
-        if ($pos===false) return $url."?showtemplate=false"; //Something's wrong
-        $pos2=$pos+strlen("index.php/"); //leave out index.php
-        if (strpos($url,"/",$pos2)===false || strpos($url,"/",$pos2)==(strlen($url)-1)) { //No prettyencoded params present
-          $newurl=substr($url,0,$pos)."index.php?".$config["query_var"]."=".substr($url,$pos2);
-          $url=$newurl."&showtemplate=false";
-        } else { //Prettyencoded params present
-          $url.="?showtemplate=false";
-        }
-      } else {
-        $url.="?showtemplate=false";
-        //$url=str_replace("//","/",$url);
-      }
+      $url .= '?showtemplate=false';
     }
     return $url;
   }
@@ -118,43 +97,47 @@ class Printing extends CMSModule {
     return $content;
   }
 	
-	function SetParameters() {	  
-		$this->RestrictUnknownParams();
-	  		
-		$this->CreateParameter('text', $this->Lang("defaultlinktext"), $this->Lang('help_text'));
-		$this->SetParameterType('text',CLEAN_STRING);
-		
-		$this->CreateParameter('pdf', "false", $this->Lang('help_pdf'));
-		$this->SetParameterType('pdf',CLEAN_STRING);
-		
-		$this->CreateParameter('popup', "false", $this->Lang('help_popup'));
-		$this->SetParameterType('popup',CLEAN_STRING);
-		
-		$this->CreateParameter('script', "false", $this->Lang('help_script'));
-		$this->SetParameterType('script',CLEAN_STRING);
+  function SetParameters() {	  
+    $this->RestrictUnknownParams();
+    $this->RegisterModulePlugin();
 
+    $this->SetParameterType('url',CLEAN_STRING);
+    $this->SetParameterType('pageid',CLEAN_INT);
+
+    $this->CreateParameter('text', $this->Lang("defaultlinktext"), $this->Lang('help_text'));
+    $this->SetParameterType('text',CLEAN_STRING);
+    
+    $this->CreateParameter('pdf', "false", $this->Lang('help_pdf'));
+    $this->SetParameterType('pdf',CLEAN_STRING);
+    
+    $this->CreateParameter('popup', "false", $this->Lang('help_popup'));
+    $this->SetParameterType('popup',CLEAN_STRING);
+    
+    $this->CreateParameter('script', "false", $this->Lang('help_script'));
+    $this->SetParameterType('script',CLEAN_STRING);
+    
     $this->CreateParameter('includetemplate', "false", $this->Lang('help_includetemplate'));
-		$this->SetParameterType('includetemplate',CLEAN_STRING);
-		
-		$this->CreateParameter('showbutton', "false", $this->Lang('help_showbutton'));
-		$this->SetParameterType('showbutton',CLEAN_STRING);
-		
-		$this->CreateParameter('class', "false", $this->Lang('help_class'));
-		$this->SetParameterType('class',CLEAN_STRING);
-		
-		$this->CreateParameter('class_img', "false", $this->Lang('help_class_img'));
-		$this->SetParameterType('class_img',CLEAN_STRING);
-		
-		$this->CreateParameter('src_img', "false", $this->Lang('help_src_img'));
-		$this->SetParameterType('src_img',CLEAN_STRING);
-		
-		$this->CreateParameter('more', "false", $this->Lang('help_more'));
-		$this->SetParameterType('more',CLEAN_STRING);
-		
-		$this->CreateParameter('onlyurl', "false", $this->Lang('help_onlyurl'));
-		$this->SetParameterType('onlyurl',CLEAN_STRING);
-
-	}
+    $this->SetParameterType('includetemplate',CLEAN_STRING);
+    
+    $this->CreateParameter('showbutton', "false", $this->Lang('help_showbutton'));
+    $this->SetParameterType('showbutton',CLEAN_STRING);
+    
+    $this->CreateParameter('class', "false", $this->Lang('help_class'));
+    $this->SetParameterType('class',CLEAN_STRING);
+    
+    $this->CreateParameter('class_img', "false", $this->Lang('help_class_img'));
+    $this->SetParameterType('class_img',CLEAN_STRING);
+    
+    $this->CreateParameter('src_img', "false", $this->Lang('help_src_img'));
+    $this->SetParameterType('src_img',CLEAN_STRING);
+    
+    $this->CreateParameter('more', "false", $this->Lang('help_more'));
+    $this->SetParameterType('more',CLEAN_STRING);
+    
+    $this->CreateParameter('onlyurl', "false", $this->Lang('help_onlyurl'));
+    $this->SetParameterType('onlyurl',CLEAN_STRING);
+    
+  }
 	
 	function VisibleToAdminUser() {
     return $this->CheckPermission('modifyprintingsettings') || $this->CheckPermission('Modify Templates');
