@@ -26,9 +26,9 @@ class Search extends CMSModule
 {
   var $_tools_loaded;
 
-  function Search()
+  function __construct()
   {
-    parent::CMSModule();
+    parent::__construct();
     $this->_tools_loaded = false;
   }
 
