@@ -40,13 +40,17 @@ class TinyMCE extends CMSModule {
 	}
 
 	function GetVersion()	{
-		return '2.5.1';
+		return '2.5.5';
 	}
 
 	function IsWYSIWYG() {
 		return true;
 	}
 
+  function HandlesEvents () {
+    return true;
+  }
+
   function HasCapability($capability, $params=array()) {
     if ($capability=="wysiwyg") return true;
     return false;
@@ -184,64 +188,59 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
 		return 'tinyMCE.triggerSave();';
 	}
 
-	function ContentPostRender(&$content) {
-		//You only get here when in frontend
-		//print r($this->cms->siteprefs); die();
-    //die();
-		if (!isset($this->cms->siteprefs['frontendwysiwyg'])) return $content;
-		if ($this->cms->siteprefs['frontendwysiwyg']!=$this->GetName()) return $content;
-		$pos=strpos(strtolower($content),"</head");
-		if ($pos===false) return $content;
-    //die();
-		$content=substr($content,0,$pos).$this->WYSIWYGGenerateHeader('',true).substr($content,$pos);
-		//$_SESSION["tiny_live_frontend"]="yes";
-		return $content;
-	}
 
 	function WYSIWYGGenerateHeader($htmlresult='', $frontend=false) {
-		global $gCms;
-
+	  global $gCms;
+	  
     $languageid=$this->GetLanguageId($frontend);
     
-		//Rewriting config-file every time, fixing the reversed toggle-box buf
-		if ($this->GetPreference("usestaticconfig")=="1") {
-			if (!$this->IsTempWritable()) {
-				echo $this->ShowErrors($this->Lang("usestaticconfigwarning"));
-			} else {
-				if ($this->GetPreference("usestaticconfig")) {
-					$this->SaveStaticConfig($frontend,$this->templateid,$languageid);
-				}
-			}
-		}
-
+    //Rewriting config-file every time, fixing the reversed toggle-box buf
+    if ($this->GetPreference("usestaticconfig")=="1") {
+      if (!$this->IsTempWritable()) {
+	echo $this->ShowErrors($this->Lang("usestaticconfigwarning"));
+      } else {
+	if ($this->GetPreference("usestaticconfig")) {
+	  $this->SaveStaticConfig($frontend,$this->templateid,$languageid);
+	}
+      }
+    }
+    
     //if ($frontend) echo "hi";
-		//$basepath = $gCms->config["root_url"].'/modules/TinyMCE/tinymce/jscripts/tiny_mce/';
-		$output="";
-
-		if ($this->wysiwygactive) {
-			$output='
+    //$basepath = $gCms->config["root_url"].'/modules/TinyMCE/tinymce/jscripts/tiny_mce/';
+    $output="";
+    
+    if ($this->wysiwygactive) {
+      $output='
 		    <script type="text/javascript" src="'.$gCms->config['root_url'].'/modules/TinyMCE/tinymce/jscripts/tiny_mce/tiny_mce.js"></script>';
-			if ($this->GetPreference("usestaticconfig")!="1") {
-        $front="";
-        if ($frontend) $front="&frontend=yes";
-				$output.='
-			  <script type="text/javascript" src="'.$gCms->config['root_url'].'/modules/TinyMCE/tinyconfig.php?templateid='.$this->templateid.'&amp;languageid='.$languageid.$front.'"></script>
+      if ($this->GetPreference("usestaticconfig")!="1") {
+	$front="";
+	$parms='';
+	if ($frontend)
+	  {
+	    $parms = '?';
+	    $front="&amp;frontend=yes";
+	  }
+	else
+	  {
+	    $parms = get_secure_param();
+	  }
+	$output.='<script type="text/javascript" src="'.$gCms->config['root_url'].'/modules/TinyMCE/tinyconfig.php'.$parms.'&amp;templateid='.$this->templateid.'&amp;languageid='.$languageid.$front.'"></script>
         ';
-			} else {
-        
-				$output.='
+      } else {
+	
+	$output.='
 			  <script type="text/javascript" src="'.$gCms->config['root_url'].'/tmp/tinyconfig.js"></script>
         ';
-			}
-		} else {
-			$output="<!-- TinyMCE Session vars empty -->";
-		}
+      }
+    } else {
+      $output="<!-- TinyMCE Session vars empty -->";
+    }
 
-		return $output;
+    return $output;
 	}
 
 	function MinimumCMSVersion() {
-		return "1.5";
+		return "1.6";
 	}
 
 	function GetHelp($lang='en_US') {
@@ -262,16 +261,18 @@ Insert Smarty {literal} around selection|{literal}|{/literal}");
 
 	function GetLanguageId($frontend=false) {
     $mylang="";
+    global $gCms;
     if ($frontend) {
       $mylang=get_site_preference('frontendlang');
     } else {
-		  $mylang=$this->cms->userprefs["default_cms_language"];
+		  $mylang=$gCms->userprefs["default_cms_language"];
     }
 		if ($mylang=="") return "en"; //Lang setting "No default selected"
 		$mylang=substr($mylang,0,2);
+    
 		switch ($mylang) {
 			case "lt" : return "en";
-			case "tw" : return strtolower($this->cms->userprefs["default_cms_language"]);
+			case "tw" : return strtolower($gCms->userprefs["default_cms_language"]);
 			default : return $mylang;
 		}
 	}
@@ -370,30 +371,35 @@ tinymce.PluginManager.add('customdropdown', tinymce.plugins.CustomDropDown);
 	
 	$link="";
 	$result="";
-	//{format : 'text'}
+   $menutext=$entry->Hierarchy()." ".$entry->MenuText();
+  if (strlen($menutext)>30) {
+    $menutext=htmlspecialchars(substr($menutext,0,30),ENT_QUOTES)." &#133;";
+  } else {
+    $menutext=htmlspecialchars($menutext,ENT_QUOTES);
+  }
 	$result.="
-					".$menu.".add({title : '".$entry->Hierarchy()." ".htmlspecialchars($entry->mMenuText,ENT_QUOTES)."', onclick : function() {
+					".$menu.".add({title : '".$menutext."', onclick : function() {
 						var sel=tinyMCE.activeEditor.selection.getContent();
-						if (sel=='') sel='".htmlspecialchars($entry->mMenuText,ENT_QUOTES)."';";
+						if (sel=='') sel='".htmlentities($entry->MenuText(),ENT_QUOTES)."';";
 	
 	if ($this->GetPreference("cmslinkerstyle","selflink")=="a") {
 		if (($config['url_rewriting'] != 'none') 
 	     /*&& $config['use_hierarchy'] == true*/) {
       if ($config['url_rewriting'] == 'mod_rewrite') {
-  		  $link = $config['root_url']."/".$entry->mHierarchyPath.$config['page_extension'];
+  		  $link = $config['root_url']."/".$entry->HierarchyPath().$config['page_extension'];
 	  	} else {	  		
-		  	$link= $config['root_url']."/index.php/".$entry->mHierarchyPath.$config['page_extension'];
+		  	$link= $config['root_url']."/index.php/".$entry->HierarchyPath().$config['page_extension'];
 		  }
 	  }	else {
 	    //if ($tiny->GetPreference("cmslinkerstyle","selflink")=="a") {
-	    $link="index.php?".$config['query_var']."=".$entry->mAlias;
+	    $link="index.php?".$config['query_var']."=".$entry->Alias();
 	    //}
 	  }
 		$result.="
 						tinyMCE.activeEditor.execCommand('mceInsertContent', false, '<a href=\"".$link."\">'+sel+'</a>');";
 	} else {
 		$result.="
-						tinyMCE.activeEditor.execCommand('mceInsertContent', false, \"{cms_selflink page='".$entry->mAlias."' text='\"+sel+\"'}\");";
+						tinyMCE.activeEditor.execCommand('mceInsertContent', false, \"{cms_selflink page='".$entry->Alias()."' text='\"+sel+\"'}\");";
 	}
 	$result.="
 					}});
@@ -401,10 +407,16 @@ tinymce.PluginManager.add('customdropdown', tinymce.plugins.CustomDropDown);
 	return $result;
 }
 function AddSub($menu,$entry,&$result) {
+  $menutext=$entry->Hierarchy()." ".$entry->MenuText();
+  if (strlen($menutext)>30) {
+    $menutext=htmlspecialchars(substr($menutext,0,30),ENT_QUOTES)." &#133;";
+  } else {
+    $menutext=htmlspecialchars($menutext,ENT_QUOTES);
+  }
 	$newmenu=$menu."m";
-	$result.="					var ".$newmenu." = ".$menu.".addMenu({title : '".$entry->Hierarchy()." ".htmlspecialchars($entry->mMenuText,ENT_QUOTES)."'});
+	$result.="					var ".$newmenu." = ".$menu.".addMenu({title : '".$menutext."'});
 ";
-	if ($entry->mType!="sectionheader") {
+	if ($entry->Type()!="sectionheader") {
 	  $result.=$this->AddEntry($newmenu,$entry);
 	  $result.="					".$newmenu.".addSeparator();
 ";
@@ -432,8 +444,8 @@ tinymce.create('tinymce.plugins.CMSLinkerPlugin', {
 
 				c.onRenderMenu.add(function(c, m) {
 ";
-
-$content_ops=$this->cms->GetContentOperations();
+global $gCms;
+$content_ops=$gCms->GetContentOperations();
 $content_array=$content_ops->GetAllContent();
 
 $level=0;
@@ -443,7 +455,7 @@ $menu="m";
 
 
 foreach ($content_array as $one) {
-	if ($one->mActive!=1) continue;
+	if ($one->Active()!=1) continue;
 	if ($one->FriendlyName() == 'Separator') {
 		continue;
 	}
@@ -456,7 +468,7 @@ foreach ($content_array as $one) {
 			
 		}
 	//if ($thislevel==$level) {
-		if ($one->mChildCount>0) {
+		if ($one->ChildCount()>0) {
 			$menu=$this->AddSub($menu,$one,$result);
 			$level++;
 		} else {
@@ -501,9 +513,11 @@ return $result;
 //print_r($_SESSION);
 
 		$config=$this->GetConfig();
+    $urlext = '?';
     if ($frontend) {
       $this->smarty->assign("isfrontend","true");
     } else {
+      $urlext=get_secure_param();
       $this->smarty->assign("isfrontend","false");
     }
 
@@ -517,8 +531,8 @@ return $result;
 			$this->smarty->assign("startupmode","none");
 		}
 		  
-		
-		$this->smarty->assign("textareas",$_SESSION["tiny_live_textareas"]);
+		if( isset($_SESSION['tiny_live_textareas']) )
+		  $this->smarty->assign("textareas",$_SESSION["tiny_live_textareas"]);
 
 		$this->smarty->assign("css",$config['root_url']."/modules/TinyMCE/stylesheet.php?templateid=".$templateid."&amp;mediatype=screen&amp;bogus=".time());
 
@@ -533,11 +547,7 @@ return $result;
 			$plugins.=",table";
 		}
 		
-    $urlext="";
-    if (isset($_SESSION[CMS_USER_KEY])) {
-      $urlext=CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
-    }
-    $this->smarty->assign("urlext",$urlext);
+		$this->smarty->assign("urlext",$urlext);
 
 		$this->smarty->assign("plugins",$plugins);
 
