@@ -5,8 +5,8 @@ if (!$this->VisibleToAdminUser()) {
 	return;
 }
 if (!isset($params["tab"]))$params["tab"]="settings";
-
-$config=$this->cms->GetConfig();
+global $gCms;
+$config=$gCms->GetConfig();
 //Just for safety
 $this->CreatePermission('allowadvancedprofile', $this->Lang('allowadvancedprofile'));
 /*
