@@ -1,5 +1,8 @@
 <?php
-
+if (!$this->VisibleToAdminUser()) {
+	$this->ShowErrors($this->Lang("accessdenied"));
+	return;
+}
 $skin = $this->GetPreference('skin',"default");
 
 $source_formatting = intval($this->GetPreference('source_formatting'));
