@@ -6,7 +6,7 @@ $this->smarty->assign('endform', $this->CreateFormEnd());
 
 $this->smarty->assign('styles_help', $this->Lang('styles_help'));
 
-$this->smarty->assign('css_styles_text', $this->Lang('css_styles_text'));
+$this->smarty->assign('css_styles_text', $this->Lang('css_styles_textz'));
 $this->smarty->assign('css_styles_input', $this->CreateTextArea(false,$id, $css_styles,'css_styles',"pagesmalltextarea","","","",'40','5'));
 $this->smarty->assign('submit', $this->CreateInputSubmit($id, "submitstyles", $this->Lang("savestyles")));
 //$this->smarty->assign('reset', $this->CreateInputSubmit($id, "resetstyles", $this->Lang("reset"),"","",$this->Lang("confirmreset")));
